@@ -2,7 +2,7 @@ pub mod version;
 
 use clap::Subcommand;
 
-use super::GeneralArgs;
+use super::GlobalArgs;
 
 /// API subcommands
 #[derive(Debug, Subcommand)]
@@ -11,9 +11,9 @@ pub enum ApiArgs {
 }
 
 impl ApiArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
         match self {
-            ApiArgs::Version(args) => args.run(general_args).await,
+            ApiArgs::Version(args) => args.run(global_args).await,
         }
     }
 }
