@@ -1,21 +1,22 @@
 use crate::{
-    actions::GeneralArgs,
+    actions::GlobalArgs,
     render::json::JsonToStdout,
     types::{context::BergContext, output::OutputMode},
 };
 
 use clap::Parser;
+use miette::IntoDiagnostic;
 
 /// Display short summary of the authenticated user account
 #[derive(Parser, Debug)]
 pub struct ApiVersionArgs {}
 
 impl ApiVersionArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
-        let version = ctx.client.get_version().await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
+        let version = ctx.client.get_version().await.into_diagnostic()?;
 
-        match general_args.output_mode {
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => match version.version {
                 Some(version) => println!("Version: {version}"),
                 None => println!("No version detected"),
