@@ -2,16 +2,16 @@ use std::fs::Permissions;
 use std::os::unix::fs::PermissionsExt;
 use std::path::PathBuf;
 
-use crate::actions::GeneralArgs;
+use crate::actions::GlobalArgs;
 use crate::client::BergClient;
-use crate::paths::berg_data_dir;
+use crate::paths::token_path;
 use crate::render::spinner::spin_until_ready;
 use crate::render::ui::confirm_with_prompt;
 use crate::types::config::BergConfig;
 use crate::types::token::Token;
-use anyhow::Context;
 use inquire::CustomUserError;
 use inquire::validator::Validation;
+use miette::{Context, IntoDiagnostic};
 
 use crate::actions::text_manipulation::input_prompt_for;
 
@@ -26,8 +26,8 @@ pub struct LoginArgs {
 }
 
 impl LoginArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let _ = general_args;
+    pub async fn run(self, _global_args: GlobalArgs) -> miette::Result<()> {
+        let config = BergConfig::new()?;
         let token = self
             .token
             .map(Token)
@@ -38,28 +38,31 @@ impl LoginArgs {
         spin_until_ready(verify_setup(&token)).await?;
 
         // this is where the token gets stored
-        let token_path = create_token_storage_path()?;
+        let token_path = create_token_storage_path(config.base_url)?;
 
         // save the token
-        std::fs::write(token_path.as_path(), token.as_str()).context("Failed to save token")?;
+        std::fs::write(token_path.as_path(), token.as_str())
+            .into_diagnostic()
+            .context("Failed to save token")?;
         // make the token secret
-        std::fs::set_permissions(token_path.as_path(), Permissions::from_mode(0o0400))?;
+        std::fs::set_permissions(token_path.as_path(), Permissions::from_mode(0o0600))
+            .into_diagnostic()?;
 
         Ok(())
     }
 }
 
-fn prompt_for_token() -> anyhow::Result<Token> {
+fn prompt_for_token() -> miette::Result<Token> {
     let config = BergConfig::new()?;
     let url = config.url()?;
-    let token_generation_url = url.join("/user/settings/applications")?;
+    let token_generation_url = url.join("/user/settings/applications").into_diagnostic()?;
     let token_generation_url = token_generation_url.as_str();
     // ask for usage of browser
     if confirm_with_prompt("Authenticating. Open Browser to generate token for `berg`?")? {
         println!(
             "\nOpening {token_generation_url:?} in the browser.\n\nPlease log in, generate a token and provide it after the following prompt:\n\n"
         );
-        webbrowser::open(token_generation_url)?;
+        webbrowser::open(token_generation_url).into_diagnostic()?;
     } else {
         println!(
             "\nYou chose not to authenticate via browser. Visit\n\n\t{}\n\nto generate a token.\n",
@@ -73,13 +76,13 @@ fn prompt_for_token() -> anyhow::Result<Token> {
     Ok(token)
 }
 
-async fn verify_setup(token: &Token) -> anyhow::Result<()> {
+async fn verify_setup(token: &Token) -> miette::Result<()> {
     let config = BergConfig::new()?;
     let base_url = config.url()?;
     let client = BergClient::new(token, base_url).context("Couldn't create `berg` client.")?;
 
     _ = client.user_get_current().await.map_err(|e| {
-        anyhow::anyhow!("Verification API call didn't contain expected information.\n\n{e}")
+        miette::miette!("Verification API call didn't contain expected information.\n\n{e}")
     })?;
 
     println!("\nAuthentication success!");
@@ -87,12 +90,15 @@ async fn verify_setup(token: &Token) -> anyhow::Result<()> {
     Ok(())
 }
 
-fn create_token_storage_path() -> anyhow::Result<PathBuf> {
-    berg_data_dir().and_then(|token_dir| {
-        std::fs::create_dir_all(&token_dir)
-            .context("Couldn't create directory for saving the token.")?;
-        Ok(token_dir.join("TOKEN"))
-    })
+fn create_token_storage_path(instance: impl AsRef<str>) -> miette::Result<PathBuf> {
+    let token_path = token_path(instance)?;
+    let token_dir = token_path
+        .parent()
+        .context("Parent directory of token path '{token_path}' should exist")?;
+    std::fs::create_dir_all(token_dir)
+        .into_diagnostic()
+        .context("Couldn't create directory for saving the token.")?;
+    Ok(token_path)
 }
 
 fn validate_token(input: &str) -> Result<Validation, CustomUserError> {
@@ -136,10 +142,10 @@ fn validate_token_length(token: &str) -> Validation {
     }
 }
 
-fn ask_for_token() -> anyhow::Result<Token> {
+fn ask_for_token() -> miette::Result<Token> {
     inquire::Text::new(input_prompt_for("Token").as_str())
         .with_validator(validate_token)
         .prompt()
         .map(Token::new)
-        .map_err(anyhow::Error::from)
+        .into_diagnostic()
 }
