@@ -1,10 +1,10 @@
-use crate::actions::GeneralArgs;
+use crate::actions::GlobalArgs;
 use crate::paths::token_path;
 use crate::render::ui::confirm_with_prompt;
 use crate::types::context::BergContext;
 
-use anyhow::Context;
 use clap::Parser;
+use miette::{Context, IntoDiagnostic};
 
 /// Logout. Delete currently stored authentication token
 #[derive(Parser, Debug)]
@@ -15,9 +15,9 @@ pub struct LogoutArgs {
 }
 
 impl LogoutArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let _ = general_args;
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let _ = global_args;
+        let ctx = BergContext::new(self, global_args).await?;
         if !ctx.args.skip_confirmation
             && !confirm_with_prompt(
                 "Logging out deletes your current token. Do you want to proceed?",
@@ -26,9 +26,11 @@ impl LogoutArgs {
             return Ok(());
         }
 
-        let token_path = token_path()?;
+        let token_path = token_path(ctx.config.base_url)?;
 
-        std::fs::remove_file(token_path).context("Failed to remove token!")?;
+        std::fs::remove_file(token_path)
+            .into_diagnostic()
+            .context("Failed to remove token!")?;
 
         Ok(())
     }
