@@ -3,7 +3,7 @@ pub mod logout;
 
 use clap::Subcommand;
 
-use super::GeneralArgs;
+use super::GlobalArgs;
 
 /// Authentication subcommands
 #[derive(Subcommand, Debug)]
@@ -13,10 +13,10 @@ pub enum AuthArgs {
 }
 
 impl AuthArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
         match self {
-            AuthArgs::Login(args) => args.run(general_args).await,
-            AuthArgs::Logout(args) => args.run(general_args).await,
+            AuthArgs::Login(args) => args.run(global_args).await,
+            AuthArgs::Logout(args) => args.run(global_args).await,
         }
     }
 }
