@@ -1,9 +1,10 @@
-use crate::actions::GeneralArgs;
+use crate::actions::GlobalArgs;
 use crate::paths::config_path;
 use crate::render::json::JsonToStdout;
 use crate::types::config::{BergConfig, ConfigLocation};
 
 use clap::Parser;
+use miette::IntoDiagnostic;
 
 /// Generate standard configuration at certain locations
 #[derive(Parser, Debug)]
@@ -24,8 +25,8 @@ pub struct ConfigGenerateArgs {
 }
 
 impl ConfigGenerateArgs {
-    pub fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let _ = general_args;
+    pub fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let _ = global_args;
 
         let config = BergConfig::new()?;
 
@@ -36,22 +37,22 @@ impl ConfigGenerateArgs {
 
                 // remove if we want to replace the file
                 if self.replace && path_file.exists() {
-                    std::fs::remove_file(path_file.clone())?;
+                    std::fs::remove_file(path_file.clone()).into_diagnostic()?;
                 }
 
                 // by now the file shouldn't exist or we have to throw an error (non-replace case)
                 if path_file.exists() {
-                    anyhow::bail!("berg config already exists at {path_file:?}!");
+                    miette::bail!("berg config already exists at {path_file:?}!");
                 }
 
-                let config_text = toml::to_string(&config)?;
-                std::fs::create_dir_all(path_dir.clone())?;
-                std::fs::write(path_file.clone(), config_text)?;
+                let config_text = toml::to_string(&config).into_diagnostic()?;
+                std::fs::create_dir_all(path_dir.clone()).into_diagnostic()?;
+                std::fs::write(path_file.clone(), config_text).into_diagnostic()?;
                 println!("Successfully created berg config at {path_file:?}");
             }
-            ConfigLocation::Stdout => match general_args.output_mode {
+            ConfigLocation::Stdout => match global_args.output_mode {
                 crate::types::output::OutputMode::Pretty => {
-                    let config_text = toml::to_string(&config)?;
+                    let config_text = toml::to_string(&config).into_diagnostic()?;
                     println!("{config_text}");
                 }
                 crate::types::output::OutputMode::Json => config.print_json()?,
