@@ -3,7 +3,7 @@ pub mod info;
 
 use clap::Subcommand;
 
-use super::GeneralArgs;
+use super::GlobalArgs;
 
 /// Config subcommands
 #[derive(Subcommand, Debug)]
@@ -13,10 +13,10 @@ pub enum ConfigArgs {
 }
 
 impl ConfigArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
         match self {
-            ConfigArgs::Info(args) => args.run(general_args),
-            ConfigArgs::Generate(args) => args.run(general_args),
+            ConfigArgs::Info(args) => args.run(global_args),
+            ConfigArgs::Generate(args) => args.run(global_args),
         }
     }
 }
