@@ -1,9 +1,9 @@
-use anyhow::Context;
 use forgejo_api::structs::{CreateIssueCommentOption, IssueListIssuesQuery};
+use miette::{Context, IntoDiagnostic};
 
 use crate::actions::issue::display_issue;
 
-use crate::actions::GeneralArgs;
+use crate::actions::GlobalArgs;
 use crate::actions::text_manipulation::select_prompt_for;
 use crate::render::json::JsonToStdout;
 use crate::render::spinner::spin_until_ready;
@@ -17,9 +17,9 @@ use clap::Parser;
 /// Add a comment to selected issue
 #[derive(Parser, Debug, Clone)]
 pub struct CommentIssueArgs {
-    /// id of the issue to comment
+    /// number of the issue to comment
     #[arg(short, long)]
-    pub id: Option<u64>,
+    pub number: Option<i64>,
 
     /// text body of the issue
     #[arg(short, long)]
@@ -27,8 +27,8 @@ pub struct CommentIssueArgs {
 }
 
 impl CommentIssueArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
         let OwnerRepo { owner, repo } = ctx.owner_repo()?;
 
         let (nr, options) = create_options(&ctx).await?;
@@ -36,9 +36,10 @@ impl CommentIssueArgs {
         let comment = ctx
             .client
             .issue_create_comment(owner.as_str(), repo.as_str(), nr, options)
-            .await?;
+            .await
+            .into_diagnostic()?;
 
-        match general_args.output_mode {
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => {
                 tracing::debug!("{comment:?}");
             }
@@ -53,19 +54,23 @@ impl CommentIssueArgs {
 
 async fn create_options(
     ctx: &BergContext<CommentIssueArgs>,
-) -> anyhow::Result<(u64, CreateIssueCommentOption)> {
+) -> miette::Result<(i64, CreateIssueCommentOption)> {
     let OwnerRepo { owner, repo } = ctx.owner_repo()?;
 
-    let selected_issue = if ctx.general_args.non_interactive {
+    let selected_issue = if ctx.global_args.non_interactive {
         None
     } else {
-        let (_, issues_list) = spin_until_ready(ctx.client.issue_list_issues(
-            owner.as_str(),
-            repo.as_str(),
-            IssueListIssuesQuery::default(),
-        ))
+        let (_, issues_list) = spin_until_ready(
+            ctx.client
+                .issue_list_issues(
+                    owner.as_str(),
+                    repo.as_str(),
+                    IssueListIssuesQuery::default(),
+                )
+                .send(),
+        )
         .await
-        .map_err(anyhow::Error::from)?;
+        .into_diagnostic()?;
 
         let selected_issue =
             fuzzy_select_with_key(&issues_list, select_prompt_for("issue"), display_issue)?;
@@ -73,18 +78,20 @@ async fn create_options(
         Some(selected_issue.clone())
     };
 
-    let nr = selected_issue
+    let nr = match selected_issue
         .as_ref()
         .context("No issue selected")
-        .and_then(|issue| Ok(issue.id.context("Selected issue had no id")? as u64))
-        .or_else(|e| {
-            ctx.args
-                .id
-                .context(e)
-                .context("You have to provide an issue number in non-interactive mode!")
-        })?;
+        .and_then(|issue| issue.number.context("Selected issue had no issue number"))
+    {
+        Ok(ok) => ok,
+        Err(e) => ctx
+            .args
+            .number
+            .context(e)
+            .context("You have to provide an issue number in non-interactive mode!")?,
+    };
 
-    let body = if ctx.general_args.non_interactive {
+    let body = if ctx.global_args.non_interactive {
         ctx.args
             .body
             .clone()
@@ -104,7 +111,7 @@ async fn create_options(
 fn get_comment_input(
     ctx: &BergContext<CommentIssueArgs>,
     issue_title: impl Into<Option<String>>,
-) -> anyhow::Result<String> {
+) -> miette::Result<String> {
     let opt_issue_title = issue_title
         .into()
         .map(|title| format!(" for issue \"{title}\""))
