@@ -1,11 +1,11 @@
-use crate::actions::GeneralArgs;
+use crate::actions::GlobalArgs;
 use crate::render::json::JsonToStdout;
 use crate::render::ui::{fuzzy_select_with_key, multi_fuzzy_select_with_key};
 use crate::types::context::BergContext;
 use crate::types::git::OwnerRepo;
 use crate::types::output::OutputMode;
-use anyhow::Context;
 use forgejo_api::structs::{CreateIssueOption, IssueGetMilestonesListQuery, IssueListLabelsQuery};
+use miette::{Context, IntoDiagnostic};
 use strum::*;
 
 use crate::actions::text_manipulation::{input_prompt_for, select_prompt_for};
@@ -44,16 +44,17 @@ enum CreatableFields {
 }
 
 impl CreateIssueArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
         let OwnerRepo { repo, owner } = ctx.owner_repo()?;
         let options = create_options(&ctx).await?;
         tracing::debug!("{options:?}");
         let issue = ctx
             .client
             .issue_create_issue(owner.as_str(), repo.as_str(), options)
-            .await?;
-        match general_args.output_mode {
+            .await
+            .into_diagnostic()?;
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => {
                 tracing::debug!("{issue:?}");
             }
@@ -63,7 +64,8 @@ impl CreateIssueArgs {
     }
 }
 
-async fn create_options(ctx: &BergContext<CreateIssueArgs>) -> anyhow::Result<CreateIssueOption> {
+async fn create_options(ctx: &BergContext<CreateIssueArgs>) -> miette::Result<CreateIssueOption> {
+    let OwnerRepo { repo, owner } = ctx.owner_repo()?;
     let title = ctx
         .args
         .title
@@ -71,30 +73,77 @@ async fn create_options(ctx: &BergContext<CreateIssueArgs>) -> anyhow::Result<Cr
         .cloned()
         .map(Ok)
         .unwrap_or_else(|| {
-            if ctx.general_args.non_interactive {
-                anyhow::bail!("You have to set an issue title!");
+            if ctx.global_args.non_interactive {
+                miette::bail!("You have to set an issue title!");
             } else {
                 inquire::Text::new(input_prompt_for("Issue Title").as_str())
                     .prompt()
-                    .map_err(anyhow::Error::from)
+                    .into_diagnostic()
             }
         })?;
 
+    let milestone = if let Some(milestone_title) = ctx.args.milestone.as_ref() {
+        let (_, milestones) = ctx
+            .client
+            .issue_get_milestones_list(owner.as_str(), repo.as_str(), Default::default())
+            .await
+            .into_diagnostic()?;
+        let selected_milestone = milestones
+            .into_iter()
+            .find(|milestone| {
+                milestone
+                    .title
+                    .as_ref()
+                    .is_some_and(|title| title == milestone_title)
+            })
+            .with_context(|| format!("Couldn't find milestone with title: {milestone_title}"))?;
+        Some(
+            selected_milestone
+                .id
+                .context("Milestone is expected to have a milestone ID!")?,
+        )
+    } else {
+        None
+    };
+
+    let labels = if let Some(requested_labels) = ctx.args.labels.as_ref() {
+        let (_, issue_labels) = ctx
+            .client
+            .issue_list_labels(owner.as_str(), repo.as_str(), Default::default())
+            .await
+            .into_diagnostic()?;
+        let labels = requested_labels
+            .iter()
+            .map(|label_name| {
+                issue_labels
+                    .iter()
+                    .find(|label| label.name.as_ref().is_some_and(|name| name == label_name))
+                    .with_context(|| format!("Label with name {label_name} doesn't exist yet"))
+                    .context("Please create all labels before using them")?
+                    .id
+                    .context("Selected label is missing an ID")
+            })
+            .collect::<Result<Vec<_>, _>>()?;
+        Some(labels)
+    } else {
+        None
+    };
+
     let mut options = CreateIssueOption {
         title,
         assignee: None,
-        assignees: None,
-        body: None,
+        assignees: ctx.args.assignees.clone(),
+        body: ctx.args.body.clone(),
         closed: None,
         due_date: None,
-        labels: None,
-        milestone: None,
+        labels,
+        milestone,
         r#ref: None,
     };
 
     options.body.replace(issue_body(ctx)?);
 
-    if !ctx.general_args.non_interactive {
+    if !ctx.global_args.non_interactive {
         let optional_data = {
             use CreatableFields::*;
             [
@@ -126,14 +175,14 @@ async fn create_options(ctx: &BergContext<CreateIssueArgs>) -> anyhow::Result<Cr
     Ok(options)
 }
 
-fn issue_body(ctx: &BergContext<CreateIssueArgs>) -> anyhow::Result<String> {
+fn issue_body(ctx: &BergContext<CreateIssueArgs>) -> miette::Result<String> {
     let body = match ctx.args.body.as_ref() {
         Some(body) => body.clone(),
         None => {
-            if ctx.general_args.non_interactive {
-                anyhow::bail!("You need to provide an issue description!");
+            if ctx.global_args.non_interactive {
+                miette::bail!("You need to provide an issue description!");
             } else {
-                ctx.editor_for("a description", "Enter a issue description")?
+                ctx.editor_for("a description", "Enter an issue description")?
             }
         }
     };
@@ -143,7 +192,7 @@ fn issue_body(ctx: &BergContext<CreateIssueArgs>) -> anyhow::Result<String> {
 async fn issue_labels(
     ctx: &BergContext<CreateIssueArgs>,
     interactive: bool,
-) -> anyhow::Result<Option<Vec<i64>>> {
+) -> miette::Result<Option<Vec<i64>>> {
     let OwnerRepo { repo, owner } = ctx.owner_repo()?;
 
     let (_, all_labels) = ctx
@@ -153,7 +202,8 @@ async fn issue_labels(
             repo.as_str(),
             IssueListLabelsQuery::default(),
         )
-        .await?;
+        .await
+        .into_diagnostic()?;
 
     let labels = match &ctx.args.labels {
         Some(label_names) => {
@@ -173,6 +223,13 @@ async fn issue_labels(
                 return Ok(None);
             }
 
+            if all_labels.is_empty() {
+                println!(
+                    "No labels available! You might want to create some via `berg label create`!"
+                );
+                return Ok(None);
+            }
+
             let selected_labels = multi_fuzzy_select_with_key(
                 &all_labels,
                 select_prompt_for("labels"),
@@ -199,13 +256,14 @@ async fn issue_labels(
 async fn issue_assignees(
     ctx: &BergContext<CreateIssueArgs>,
     interactive: bool,
-) -> anyhow::Result<Option<Vec<String>>> {
+) -> miette::Result<Option<Vec<String>>> {
     let OwnerRepo { repo, owner } = ctx.owner_repo()?;
 
     let (_, all_assignees) = ctx
         .client
         .repo_get_assignees(owner.as_str(), repo.as_str())
-        .await?;
+        .await
+        .into_diagnostic()?;
     let assignees = match &ctx.args.assignees {
         Some(assignees_names) => Some(assignees_names.clone()),
         None => {
@@ -241,7 +299,7 @@ async fn issue_assignees(
 async fn issue_milestone(
     ctx: &BergContext<CreateIssueArgs>,
     interactive: bool,
-) -> anyhow::Result<Option<i64>> {
+) -> miette::Result<Option<i64>> {
     let OwnerRepo { repo, owner } = ctx.owner_repo()?;
 
     let (_, all_milestones) = ctx
@@ -251,7 +309,8 @@ async fn issue_milestone(
             repo.as_str(),
             IssueGetMilestonesListQuery::default(),
         )
-        .await?;
+        .await
+        .into_diagnostic()?;
 
     let milestone = match &ctx.args.milestone {
         Some(milestone_name) => Some(
