@@ -8,7 +8,7 @@ pub mod view;
 
 use clap::Subcommand;
 
-use super::GeneralArgs;
+use super::GlobalArgs;
 
 /// Issue subcommands
 #[derive(Subcommand, Debug)]
@@ -21,13 +21,13 @@ pub enum IssueArgs {
 }
 
 impl IssueArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
         match self {
-            IssueArgs::List(args) => args.run(general_args).await,
-            IssueArgs::Create(args) => args.run(general_args).await,
-            IssueArgs::Comment(args) => args.run(general_args).await,
-            IssueArgs::View(args) => args.run(general_args).await,
-            IssueArgs::Edit(args) => args.run(general_args).await,
+            IssueArgs::List(args) => args.run(global_args).await,
+            IssueArgs::Create(args) => args.run(global_args).await,
+            IssueArgs::Comment(args) => args.run(global_args).await,
+            IssueArgs::View(args) => args.run(global_args).await,
+            IssueArgs::Edit(args) => args.run(global_args).await,
         }
     }
 }
