@@ -1,17 +1,17 @@
 use crate::render::comment::render_comment;
 use crate::render::datetime::render_datetime_and_info;
 use crate::render::json::JsonToStdout;
-use crate::render::option::option_display;
+use crate::render::option::{option_debug_display, option_display};
 use crate::render::spinner::spin_until_ready;
 use crate::render::ui::fuzzy_select_with_key;
 use crate::types::api::state_type::ViewStateType;
 use crate::types::context::BergContext;
 use crate::types::output::OutputMode;
-use crate::{actions::GeneralArgs, types::git::OwnerRepo};
-use anyhow::Context;
+use crate::{actions::GlobalArgs, types::git::OwnerRepo};
 use forgejo_api::structs::{
     Issue, IssueGetCommentsQuery, IssueListIssuesQuery, IssueListIssuesQueryState,
 };
+use miette::{Context, IntoDiagnostic};
 
 use crate::actions::text_manipulation::select_prompt_for;
 
@@ -22,6 +22,9 @@ use clap::Parser;
 /// View details of selected issue
 #[derive(Parser, Debug)]
 pub struct ViewIssueArgs {
+    /// Optionally, specify a selected issue in the command line
+    pub index: Option<i64>,
+
     /// Select from issues with the chosen state
     #[arg(short, long, value_enum, default_value_t = ViewStateType::All)]
     pub state: ViewStateType,
@@ -32,36 +35,71 @@ pub struct ViewIssueArgs {
 }
 
 impl ViewIssueArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
         let OwnerRepo { repo, owner } = ctx.owner_repo()?;
         let state = match ctx.args.state {
             ViewStateType::Closed => IssueListIssuesQueryState::Closed,
             ViewStateType::Open => IssueListIssuesQueryState::Open,
             ViewStateType::All => IssueListIssuesQueryState::All,
         };
-        let (_, issues_list) = spin_until_ready(ctx.client.issue_list_issues(
-            owner.as_str(),
-            repo.as_str(),
-            IssueListIssuesQuery {
-                state: Some(state),
-                ..Default::default()
-            },
-        ))
-        .await?;
+        let selected_issue = if let Some(index) = ctx.args.index {
+            ctx.client
+                .issue_get_issue(owner.as_str(), repo.as_str(), index)
+                .await
+                .into_diagnostic()?
+        } else {
+            if ctx.global_args.non_interactive {
+                miette::bail!("non-interactive mode enabled. You have to specify an issue #number");
+            };
+            let (_, issues_list) = spin_until_ready(
+                ctx.client
+                    .issue_list_issues(
+                        owner.as_str(),
+                        repo.as_str(),
+                        IssueListIssuesQuery {
+                            state: Some(state),
+                            ..Default::default()
+                        },
+                    )
+                    .send(),
+            )
+            .await
+            .into_diagnostic()?;
 
-        let selected_issue =
-            fuzzy_select_with_key(&issues_list, select_prompt_for("issue"), display_issue)?;
+            fuzzy_select_with_key(&issues_list, select_prompt_for("issue"), display_issue)
+                .cloned()?
+        };
 
-        match general_args.output_mode {
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => {
                 if ctx.args.comments {
-                    spin_until_ready(present_issue_comments(&ctx, selected_issue)).await?;
+                    spin_until_ready(present_issue_comments(&ctx, &selected_issue)).await?;
                 } else {
-                    present_issue_overview(&ctx, selected_issue);
+                    present_issue_overview(&ctx, &selected_issue);
+                }
+            }
+            OutputMode::Json => {
+                if ctx.args.comments {
+                    let index = selected_issue
+                        .number
+                        .context("Selected issue has to have a valid issue number")?;
+                    let (_, comments) = ctx
+                        .client
+                        .issue_get_comments(
+                            owner.as_str(),
+                            repo.as_str(),
+                            index,
+                            IssueGetCommentsQuery::default(),
+                        )
+                        .send()
+                        .await
+                        .into_diagnostic()?;
+                    comments.print_json()?;
+                } else {
+                    selected_issue.print_json()?;
                 }
             }
-            OutputMode::Json => selected_issue.print_json()?,
         }
 
         Ok(())
@@ -72,9 +110,8 @@ fn present_issue_overview(ctx: &BergContext<ViewIssueArgs>, issue: &Issue) {
     let days_passed_since_creation =
         option_display(&issue.created_at.as_ref().map(render_datetime_and_info));
 
-    let mut table = ctx.make_table();
-
-    table
+    let table = ctx
+        .make_table()
         .set_header(vec![option_display(
             &issue.id.as_ref().map(|id| format!("Issue #{}", id)),
         )])
@@ -90,6 +127,10 @@ fn present_issue_overview(ctx: &BergContext<ViewIssueArgs>, issue: &Issue) {
                     .join(", ")
             })),
         ])
+        .add_row(vec![
+            String::from("State"),
+            option_debug_display(&issue.state),
+        ])
         .add_row(vec![
             String::from("Description"),
             option_display(&issue.body),
@@ -101,8 +142,8 @@ fn present_issue_overview(ctx: &BergContext<ViewIssueArgs>, issue: &Issue) {
 async fn present_issue_comments(
     ctx: &BergContext<ViewIssueArgs>,
     issue: &Issue,
-) -> anyhow::Result<()> {
-    let id = issue.id.context("Issue has no Id")?;
+) -> miette::Result<()> {
+    let index = issue.number.context("Issue has no issue number")?;
     let OwnerRepo { repo, owner } = ctx.owner_repo()?;
     let (header, comments) = {
         let (_, comments_list) = ctx
@@ -110,13 +151,15 @@ async fn present_issue_comments(
             .issue_get_comments(
                 owner.as_str(),
                 repo.as_str(),
-                id as u64,
+                index,
                 IssueGetCommentsQuery::default(),
             )
-            .await?;
+            .send()
+            .await
+            .into_diagnostic()?;
         let header = format!(
             "Issue #{} {}",
-            id,
+            index,
             if comments_list.is_empty() {
                 "(no comments)"
             } else {
@@ -126,15 +169,14 @@ async fn present_issue_comments(
         (header, comments_list)
     };
 
-    let mut table = ctx.make_table();
-
-    table
+    let table = ctx
+        .make_table()
         .add_row(vec![header])
         .add_rows(comments.into_iter().filter_map(|comment| {
             let username = comment.user.as_ref()?.login.as_ref()?.as_str();
             let creation_time = comment.created_at.as_ref()?;
             let comment = comment.body.as_ref()?;
-            let comment = render_comment(&ctx.config, username, creation_time, comment);
+            let comment = render_comment(username, creation_time, comment);
             Some(vec![comment])
         }));
 
