@@ -1,10 +1,11 @@
 use crate::render::color::mk_color_validator;
 use crate::render::json::JsonToStdout;
-use crate::{actions::GeneralArgs, types::git::OwnerRepo};
+use crate::{actions::GlobalArgs, types::git::OwnerRepo};
 
 use crate::render::ui::multi_fuzzy_select_with_key;
 use crate::types::context::BergContext;
 use forgejo_api::structs::CreateLabelOption;
+use miette::IntoDiagnostic;
 use strum::*;
 
 use crate::actions::text_manipulation::input_prompt_for;
@@ -34,16 +35,17 @@ enum CreatableFields {
 }
 
 impl CreateLabelArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
 
         let OwnerRepo { repo, owner } = ctx.owner_repo()?;
         let options = create_options(&ctx).await?;
         let label = ctx
             .client
             .issue_create_label(owner.as_str(), repo.as_str(), options)
-            .await?;
-        match general_args.output_mode {
+            .await
+            .into_diagnostic()?;
+        match ctx.global_args.output_mode {
             crate::types::output::OutputMode::Pretty => {
                 tracing::debug!("{label:?}");
             }
@@ -53,10 +55,17 @@ impl CreateLabelArgs {
     }
 }
 
-async fn create_options(ctx: &BergContext<CreateLabelArgs>) -> anyhow::Result<CreateLabelOption> {
+async fn create_options(ctx: &BergContext<CreateLabelArgs>) -> miette::Result<CreateLabelOption> {
     let name = match ctx.args.name.as_ref().cloned() {
         Some(name) => name,
-        None => inquire::Text::new(input_prompt_for("Label Name").as_str()).prompt()?,
+        None => {
+            if ctx.global_args.non_interactive {
+                miette::bail!("You need to specify a name in non-interactive mode!");
+            }
+            inquire::Text::new(input_prompt_for("Label Name").as_str())
+                .prompt()
+                .into_diagnostic()?
+        }
     };
 
     let color = ctx
@@ -69,34 +78,36 @@ async fn create_options(ctx: &BergContext<CreateLabelArgs>) -> anyhow::Result<Cr
     let mut options = CreateLabelOption {
         name,
         color,
-        description: None,
+        description: ctx.args.description.clone(),
         exclusive: None,
         is_archived: None,
     };
 
-    let optional_data = {
-        use CreatableFields::*;
-        [
-            (Description, ctx.args.description.is_none()),
-            (Color, ctx.args.color.is_none()),
-        ]
-        .into_iter()
-        .filter_map(|(name, missing)| missing.then_some(name))
-        .collect::<Vec<_>>()
-    };
+    if !ctx.global_args.non_interactive {
+        let optional_data = {
+            use CreatableFields::*;
+            [
+                (Description, ctx.args.description.is_none()),
+                (Color, ctx.args.color.is_none()),
+            ]
+            .into_iter()
+            .filter_map(|(name, missing)| missing.then_some(name))
+            .collect::<Vec<_>>()
+        };
 
-    let chosen_optionals = multi_fuzzy_select_with_key(
-        &optional_data,
-        "Choose optional properties",
-        |_| false,
-        |o| o.to_string(),
-    )?;
+        let chosen_optionals = multi_fuzzy_select_with_key(
+            &optional_data,
+            "Choose optional properties",
+            |_| false,
+            |o| o.to_string(),
+        )?;
 
-    {
-        use CreatableFields::*;
-        options.description = label_description(ctx, chosen_optionals.contains(&&Description))?;
-        if let Some(color) = label_color(ctx, chosen_optionals.contains(&&Color))? {
-            options.color = color;
+        {
+            use CreatableFields::*;
+            options.description = label_description(ctx, chosen_optionals.contains(&&Description))?;
+            if let Some(color) = label_color(ctx, chosen_optionals.contains(&&Color))? {
+                options.color = color;
+            }
         }
     }
 
@@ -106,7 +117,7 @@ async fn create_options(ctx: &BergContext<CreateLabelArgs>) -> anyhow::Result<Cr
 fn label_description(
     ctx: &BergContext<CreateLabelArgs>,
     interactive: bool,
-) -> anyhow::Result<Option<String>> {
+) -> miette::Result<Option<String>> {
     let description = match ctx.args.description.as_ref() {
         Some(desc) => desc.clone(),
         None => {
@@ -122,7 +133,7 @@ fn label_description(
 fn label_color(
     ctx: &BergContext<CreateLabelArgs>,
     interactive: bool,
-) -> anyhow::Result<Option<String>> {
+) -> miette::Result<Option<String>> {
     let color = match ctx.args.color.as_ref() {
         Some(color) => color.clone(),
         None => {
@@ -132,7 +143,8 @@ fn label_color(
             mk_color_validator(inquire::Text::new(
                 input_prompt_for("Enter a color").as_str(),
             ))
-            .prompt()?
+            .prompt()
+            .into_diagnostic()?
         }
     };
     Ok(Some(color))
