@@ -1,8 +1,9 @@
 use forgejo_api::structs::IssueListLabelsQuery;
+use miette::IntoDiagnostic;
 
 use crate::actions::label::display_label;
 
-use crate::actions::GeneralArgs;
+use crate::actions::GlobalArgs;
 use crate::render::spinner::spin_until_ready;
 use crate::render::ui::multi_fuzzy_select_with_key;
 
@@ -17,17 +18,24 @@ use clap::Parser;
 pub struct DeleteLabelArgs {}
 
 impl DeleteLabelArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let _ = general_args;
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let _ = global_args;
+        let ctx = BergContext::new(self, global_args).await?;
 
         let OwnerRepo { repo, owner } = ctx.owner_repo()?;
-        let (_, labels_list) = spin_until_ready(ctx.client.issue_list_labels(
-            owner.as_str(),
-            repo.as_str(),
-            IssueListLabelsQuery::default(),
-        ))
-        .await?;
+        let (_, labels_list) = spin_until_ready(
+            ctx.client
+                .issue_list_labels(
+                    owner.as_str(),
+                    repo.as_str(),
+                    IssueListLabelsQuery::default(),
+                )
+                .send(),
+        )
+        .await
+        .into_diagnostic()?;
+
+        // TODO: cleanup AI generated code ... no non-interactive version
 
         let selected_labels = multi_fuzzy_select_with_key(
             &labels_list,
@@ -38,8 +46,9 @@ impl DeleteLabelArgs {
 
         for id in selected_labels.into_iter().filter_map(|label| label.id) {
             ctx.client
-                .issue_delete_label(owner.as_str(), repo.as_str(), id as u64)
-                .await?;
+                .issue_delete_label(owner.as_str(), repo.as_str(), id)
+                .await
+                .into_diagnostic()?;
         }
 
         Ok(())
