@@ -1,4 +1,4 @@
-use crate::actions::GeneralArgs;
+use crate::actions::GlobalArgs;
 use crate::actions::label::display_label;
 
 use crate::render::color::mk_color_validator;
@@ -8,8 +8,8 @@ use crate::render::ui::{fuzzy_select_with_key, multi_fuzzy_select_with_key};
 use crate::types::context::BergContext;
 use crate::types::git::OwnerRepo;
 use crate::types::output::OutputMode;
-use anyhow::Context;
 use forgejo_api::structs::{EditLabelOption, IssueListLabelsQuery, Label};
+use miette::{Context, IntoDiagnostic};
 use strum::{Display, VariantArray};
 
 use crate::actions::text_manipulation::{input_prompt_for, select_prompt_for};
@@ -28,10 +28,11 @@ enum EditableFields {
 }
 
 impl EditLabelArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
 
         let OwnerRepo { repo, owner } = ctx.owner_repo()?;
+        // TODO: cleanup AI code ... no non-interactive version
         let label = select_label(&ctx).await?;
         let label_id = label.id.context("Selected label doesn't have an ID")?;
 
@@ -39,10 +40,11 @@ impl EditLabelArgs {
 
         let updated_label = ctx
             .client
-            .issue_edit_label(owner.as_str(), repo.as_str(), label_id as u64, options)
-            .await?;
+            .issue_edit_label(owner.as_str(), repo.as_str(), label_id, options)
+            .await
+            .into_diagnostic()?;
 
-        match general_args.output_mode {
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => {
                 tracing::debug!("{updated_label:?}");
             }
@@ -53,17 +55,22 @@ impl EditLabelArgs {
     }
 }
 
-async fn select_label(ctx: &BergContext<EditLabelArgs>) -> anyhow::Result<Label> {
+async fn select_label(ctx: &BergContext<EditLabelArgs>) -> miette::Result<Label> {
     let OwnerRepo { repo, owner } = ctx.owner_repo()?;
-    let (_, labels_list) = spin_until_ready(ctx.client.issue_list_labels(
-        owner.as_str(),
-        repo.as_str(),
-        IssueListLabelsQuery::default(),
-    ))
-    .await?;
+    let (_, labels_list) = spin_until_ready(
+        ctx.client
+            .issue_list_labels(
+                owner.as_str(),
+                repo.as_str(),
+                IssueListLabelsQuery::default(),
+            )
+            .send(),
+    )
+    .await
+    .into_diagnostic()?;
 
     if labels_list.is_empty() {
-        anyhow::bail!("No labels found in this repository");
+        miette::bail!("No labels found in this repository");
     }
 
     fuzzy_select_with_key(&labels_list, select_prompt_for("label"), display_label).cloned()
@@ -72,7 +79,7 @@ async fn select_label(ctx: &BergContext<EditLabelArgs>) -> anyhow::Result<Label>
 async fn create_options(
     ctx: &BergContext<EditLabelArgs>,
     label: &Label,
-) -> anyhow::Result<EditLabelOption> {
+) -> miette::Result<EditLabelOption> {
     let selected_update_fields = multi_fuzzy_select_with_key(
         EditableFields::VARIANTS,
         select_prompt_for("options"),
@@ -111,7 +118,7 @@ async fn create_options(
 async fn label_name(
     ctx: &BergContext<EditLabelArgs>,
     current_name: Option<String>,
-) -> anyhow::Result<String> {
+) -> miette::Result<String> {
     ctx.editor_for(
         "Choose a new label name",
         current_name.as_deref().unwrap_or("Enter a label name"),
@@ -121,7 +128,7 @@ async fn label_name(
 async fn label_description(
     ctx: &BergContext<EditLabelArgs>,
     current_description: Option<String>,
-) -> anyhow::Result<String> {
+) -> miette::Result<String> {
     ctx.editor_for(
         "a description",
         current_description
@@ -133,11 +140,11 @@ async fn label_description(
 async fn label_color(
     _ctx: &BergContext<EditLabelArgs>,
     current_color: Option<String>,
-) -> anyhow::Result<String> {
+) -> miette::Result<String> {
     mk_color_validator(
         inquire::Text::new(input_prompt_for("Enter a color").as_str())
             .with_default(current_color.as_deref().unwrap_or("Enter a label color")),
     )
     .prompt()
-    .map_err(anyhow::Error::from)
+    .into_diagnostic()
 }
