@@ -1,6 +1,7 @@
 use forgejo_api::structs::{IssueListLabelsQuery, Label};
+use miette::IntoDiagnostic;
 
-use crate::actions::GeneralArgs;
+use crate::actions::GlobalArgs;
 use crate::render::json::JsonToStdout;
 use crate::render::option::option_display;
 use crate::render::spinner::spin_until_ready;
@@ -20,18 +21,23 @@ pub struct ListLabelsArgs {
 }
 
 impl ListLabelsArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
 
         let OwnerRepo { repo, owner } = ctx.owner_repo()?;
-        let (_, labels_list) = spin_until_ready(ctx.client.issue_list_labels(
-            owner.as_str(),
-            repo.as_str(),
-            IssueListLabelsQuery::default(),
-        ))
-        .await?;
+        let (_, labels_list) = spin_until_ready(
+            ctx.client
+                .issue_list_labels(
+                    owner.as_str(),
+                    repo.as_str(),
+                    IssueListLabelsQuery::default(),
+                )
+                .send(),
+        )
+        .await
+        .into_diagnostic()?;
 
-        match general_args.output_mode {
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => {
                 present_labels_list(&ctx, labels_list);
             }
@@ -45,9 +51,8 @@ impl ListLabelsArgs {
 fn present_labels_list(ctx: &BergContext<ListLabelsArgs>, labels: Vec<Label>) {
     let labels_empty = labels.is_empty();
 
-    let mut table = ctx.make_table();
-
-    table
+    let table = ctx
+        .make_table()
         .set_header(vec![format!(
             "Labels{}",
             if labels_empty {
