@@ -7,7 +7,7 @@ pub mod list;
 
 use clap::Subcommand;
 
-use super::GeneralArgs;
+use super::GlobalArgs;
 
 /// Label subcommands
 #[derive(Subcommand, Debug)]
@@ -19,12 +19,12 @@ pub enum LabelArgs {
 }
 
 impl LabelArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
         match self {
-            LabelArgs::List(args) => args.run(general_args).await,
-            LabelArgs::Create(args) => args.run(general_args).await,
-            LabelArgs::Delete(args) => args.run(general_args).await,
-            LabelArgs::Edit(args) => args.run(general_args).await,
+            LabelArgs::List(args) => args.run(global_args).await,
+            LabelArgs::Create(args) => args.run(global_args).await,
+            LabelArgs::Delete(args) => args.run(global_args).await,
+            LabelArgs::Edit(args) => args.run(global_args).await,
         }
     }
 }
