@@ -2,8 +2,9 @@ use crate::render::json::JsonToStdout;
 use crate::render::ui::multi_fuzzy_select_with_key;
 use crate::types::context::BergContext;
 use crate::types::output::OutputMode;
-use crate::{actions::GeneralArgs, types::git::OwnerRepo};
+use crate::{actions::GlobalArgs, types::git::OwnerRepo};
 use forgejo_api::structs::CreateMilestoneOption;
+use miette::IntoDiagnostic;
 use strum::{Display, VariantArray};
 
 use crate::actions::text_manipulation::input_prompt_for;
@@ -29,16 +30,17 @@ enum CreatableFields {
 }
 
 impl CreateMilestoneArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
 
         let OwnerRepo { owner, repo } = ctx.owner_repo()?;
         let options = create_options(&ctx).await?;
         let milestone = ctx
             .client
             .issue_create_milestone(owner.as_str(), repo.as_str(), options)
-            .await?;
-        match general_args.output_mode {
+            .await
+            .into_diagnostic()?;
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => {
                 tracing::debug!("{milestone:?}");
             }
@@ -50,7 +52,7 @@ impl CreateMilestoneArgs {
 
 async fn create_options(
     ctx: &BergContext<CreateMilestoneArgs>,
-) -> anyhow::Result<CreateMilestoneOption> {
+) -> miette::Result<CreateMilestoneOption> {
     let mut options = CreateMilestoneOption {
         description: None,
         due_on: None,
@@ -88,14 +90,16 @@ async fn create_options(
 fn milestone_title(
     ctx: &BergContext<CreateMilestoneArgs>,
     interactive: bool,
-) -> anyhow::Result<Option<String>> {
+) -> miette::Result<Option<String>> {
     let title = match ctx.args.title.as_ref() {
         Some(title) => title.clone(),
         None => {
             if !interactive {
                 return Ok(None);
             }
-            inquire::Text::new(input_prompt_for("Label Name").as_str()).prompt()?
+            inquire::Text::new(input_prompt_for("Label Name").as_str())
+                .prompt()
+                .into_diagnostic()?
         }
     };
     Ok(Some(title))
@@ -104,7 +108,7 @@ fn milestone_title(
 fn milestone_description(
     ctx: &BergContext<CreateMilestoneArgs>,
     interactive: bool,
-) -> anyhow::Result<Option<String>> {
+) -> miette::Result<Option<String>> {
     let description = match ctx.args.description.as_ref() {
         Some(desc) => desc.clone(),
         None => {
