@@ -1,16 +1,17 @@
-use crate::actions::GeneralArgs;
+use crate::actions::GlobalArgs;
 use crate::render::json::JsonToStdout;
 use crate::render::spinner::spin_until_ready;
 use crate::render::ui::fuzzy_select_with_key;
 use crate::render::ui::multi_fuzzy_select_with_key;
+use crate::render::ui::select_state;
 use crate::types::context::BergContext;
 use crate::types::git::OwnerRepo;
 use crate::types::output::OutputMode;
-use anyhow::Context;
 use forgejo_api::structs::EditMilestoneOption;
 use forgejo_api::structs::IssueGetMilestonesListQuery;
 use forgejo_api::structs::Milestone;
-use forgejo_api::structs::StateType;
+use miette::Context;
+use miette::IntoDiagnostic;
 use strum::Display;
 use strum::VariantArray;
 
@@ -33,31 +34,24 @@ enum EditableFields {
 }
 
 impl EditMilestoneArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
 
         let OwnerRepo { owner, repo } = ctx.owner_repo()?;
         let milestone = select_milestone(&ctx).await?;
         let milestone_id_or_name = milestone
             .id
-            .as_ref()
-            .map(|id| id.to_string())
-            .or_else(|| milestone.title.clone())
-            .context("Selected milestone doesn't have an ID or Name")?;
+            .context("Selected milestone doesn't have an ID")?;
 
         let options = create_options(&ctx, &milestone).await?;
 
         let updated_milestone = ctx
             .client
-            .issue_edit_milestone(
-                owner.as_str(),
-                repo.as_str(),
-                milestone_id_or_name.as_str(),
-                options,
-            )
-            .await?;
+            .issue_edit_milestone(owner.as_str(), repo.as_str(), milestone_id_or_name, options)
+            .await
+            .into_diagnostic()?;
 
-        match general_args.output_mode {
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => {
                 tracing::debug!("{updated_milestone:?}");
             }
@@ -68,17 +62,22 @@ impl EditMilestoneArgs {
     }
 }
 
-async fn select_milestone(ctx: &BergContext<EditMilestoneArgs>) -> anyhow::Result<Milestone> {
+async fn select_milestone(ctx: &BergContext<EditMilestoneArgs>) -> miette::Result<Milestone> {
     let OwnerRepo { owner, repo } = ctx.owner_repo()?;
-    let (_, milestones_list) = spin_until_ready(ctx.client.issue_get_milestones_list(
-        owner.as_str(),
-        repo.as_str(),
-        IssueGetMilestonesListQuery::default(),
-    ))
-    .await?;
+    let (_, milestones_list) = spin_until_ready(
+        ctx.client
+            .issue_get_milestones_list(
+                owner.as_str(),
+                repo.as_str(),
+                IssueGetMilestonesListQuery::default(),
+            )
+            .send(),
+    )
+    .await
+    .into_diagnostic()?;
 
     if milestones_list.is_empty() {
-        anyhow::bail!("No milestones found in this repository");
+        miette::bail!("No milestones found in this repository");
     }
 
     fuzzy_select_with_key(
@@ -92,7 +91,7 @@ async fn select_milestone(ctx: &BergContext<EditMilestoneArgs>) -> anyhow::Resul
 async fn create_options(
     ctx: &BergContext<EditMilestoneArgs>,
     milestone: &Milestone,
-) -> anyhow::Result<EditMilestoneOption> {
+) -> miette::Result<EditMilestoneOption> {
     let selected_update_fields = multi_fuzzy_select_with_key(
         EditableFields::VARIANTS,
         select_prompt_for("options"),
@@ -115,9 +114,7 @@ async fn create_options(
     }
     if selected_update_fields.contains(&&EditableFields::State) {
         let current_state = milestone.state.as_ref().cloned();
-        options
-            .state
-            .replace(milestone_state(ctx, current_state).await?);
+        options.state.replace(select_state(current_state)?);
     }
     if selected_update_fields.contains(&&EditableFields::Description) {
         let current_description = milestone.description.as_ref().cloned();
@@ -132,7 +129,7 @@ async fn create_options(
 async fn milestone_title(
     _ctx: &BergContext<EditMilestoneArgs>,
     current_title: Option<String>,
-) -> anyhow::Result<String> {
+) -> miette::Result<String> {
     inquire::Text::new(input_prompt_for("Choose a new milestone title").as_str())
         .with_default(
             current_title
@@ -140,26 +137,13 @@ async fn milestone_title(
                 .unwrap_or("Enter a milestone title"),
         )
         .prompt()
-        .map_err(anyhow::Error::from)
-}
-
-async fn milestone_state(
-    _ctx: &BergContext<EditMilestoneArgs>,
-    _current_state: Option<StateType>,
-) -> anyhow::Result<String> {
-    let selected_state = fuzzy_select_with_key(
-        &[StateType::Open, StateType::Closed],
-        select_prompt_for("states"),
-        |f| format!("{f:?}"),
-    )
-    .cloned()?;
-    Ok(format!("{selected_state:?}"))
+        .into_diagnostic()
 }
 
 async fn milestone_description(
     ctx: &BergContext<EditMilestoneArgs>,
     current_description: Option<String>,
-) -> anyhow::Result<String> {
+) -> miette::Result<String> {
     ctx.editor_for(
         "a description",
         current_description
