@@ -3,9 +3,10 @@ use crate::render::option::option_display;
 use crate::render::spinner::spin_until_ready;
 use crate::types::context::BergContext;
 use crate::types::git::OwnerRepo;
-use crate::{actions::GeneralArgs, types::output::OutputMode};
+use crate::{actions::GlobalArgs, types::output::OutputMode};
 use clap::Parser;
 use forgejo_api::structs::{IssueGetMilestonesListQuery, Milestone};
+use miette::IntoDiagnostic;
 
 /// List all milestones in the current repository
 #[derive(Parser, Debug)]
@@ -16,18 +17,23 @@ pub struct ListMilestonesArgs {
 }
 
 impl ListMilestonesArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
 
         let OwnerRepo { repo, owner } = ctx.owner_repo()?;
-        let (_, milestones_list) = spin_until_ready(ctx.client.issue_get_milestones_list(
-            owner.as_str(),
-            repo.as_str(),
-            IssueGetMilestonesListQuery::default(),
-        ))
-        .await?;
+        let (_, milestones_list) = spin_until_ready(
+            ctx.client
+                .issue_get_milestones_list(
+                    owner.as_str(),
+                    repo.as_str(),
+                    IssueGetMilestonesListQuery::default(),
+                )
+                .send(),
+        )
+        .await
+        .into_diagnostic()?;
 
-        match general_args.output_mode {
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => {
                 present_milestones_list(&ctx, milestones_list);
             }
@@ -41,9 +47,8 @@ impl ListMilestonesArgs {
 fn present_milestones_list(ctx: &BergContext<ListMilestonesArgs>, milestones: Vec<Milestone>) {
     let milestones_empty = milestones.is_empty();
 
-    let mut table = ctx.make_table();
-
-    table
+    let table = ctx
+        .make_table()
         .set_header(vec![format!(
             "Milestones{}",
             if milestones_empty {
