@@ -7,7 +7,7 @@ pub mod view;
 
 use clap::Subcommand;
 
-use super::GeneralArgs;
+use super::GlobalArgs;
 
 /// Milestone subcommands
 #[derive(Subcommand, Debug)]
@@ -19,12 +19,12 @@ pub enum MilestoneArgs {
 }
 
 impl MilestoneArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
         match self {
-            MilestoneArgs::List(args) => args.run(general_args).await,
-            MilestoneArgs::View(args) => args.run(general_args).await,
-            MilestoneArgs::Create(args) => args.run(general_args).await,
-            MilestoneArgs::Edit(args) => args.run(general_args).await,
+            MilestoneArgs::List(args) => args.run(global_args).await,
+            MilestoneArgs::View(args) => args.run(global_args).await,
+            MilestoneArgs::Create(args) => args.run(global_args).await,
+            MilestoneArgs::Edit(args) => args.run(global_args).await,
         }
     }
 }
