@@ -1,8 +1,9 @@
 use forgejo_api::structs::{
     IssueGetMilestonesListQuery, IssueListIssuesQuery, Milestone, StateType,
 };
+use miette::IntoDiagnostic;
 
-use crate::actions::GeneralArgs;
+use crate::actions::GlobalArgs;
 use crate::render::datetime::render_datetime_regular;
 use crate::render::json::JsonToStdout;
 use crate::render::option::{option_debug_display, option_display};
@@ -28,16 +29,21 @@ pub struct ViewMilestonesArgs {
 }
 
 impl ViewMilestonesArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
 
         let OwnerRepo { repo, owner } = ctx.owner_repo()?;
-        let (_, milestones_list) = spin_until_ready(ctx.client.issue_get_milestones_list(
-            owner.as_str(),
-            repo.as_str(),
-            IssueGetMilestonesListQuery::default(),
-        ))
-        .await?;
+        let (_, milestones_list) = spin_until_ready(
+            ctx.client
+                .issue_get_milestones_list(
+                    owner.as_str(),
+                    repo.as_str(),
+                    IssueGetMilestonesListQuery::default(),
+                )
+                .send(),
+        )
+        .await
+        .into_diagnostic()?;
 
         let selected_milestone = fuzzy_select_with_key(
             &milestones_list,
@@ -45,7 +51,7 @@ impl ViewMilestonesArgs {
             display_milestone,
         )?;
 
-        match general_args.output_mode {
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => {
                 present_milestone_overview(&ctx, selected_milestone).await?;
             }
@@ -59,23 +65,26 @@ impl ViewMilestonesArgs {
 async fn present_milestone_overview(
     ctx: &BergContext<ViewMilestonesArgs>,
     milestone: &Milestone,
-) -> anyhow::Result<()> {
+) -> miette::Result<()> {
     let OwnerRepo { repo, owner } = ctx.owner_repo()?;
     let (_, issues_list) = spin_until_ready(
-        ctx.client.issue_list_issues(
-            owner.as_str(),
-            repo.as_str(),
-            IssueListIssuesQuery {
-                milestones: milestone
-                    .id
-                    .as_ref()
-                    .map(|id| id.to_string())
-                    .or_else(|| milestone.title.clone()),
-                ..Default::default()
-            },
-        ),
+        ctx.client
+            .issue_list_issues(
+                owner.as_str(),
+                repo.as_str(),
+                IssueListIssuesQuery {
+                    milestones: milestone
+                        .id
+                        .as_ref()
+                        .map(|id| id.to_string())
+                        .or_else(|| milestone.title.clone()),
+                    ..Default::default()
+                },
+            )
+            .send(),
     )
-    .await?;
+    .await
+    .into_diagnostic()?;
 
     let mut milestone_issues = issues_list
         .iter()
@@ -102,9 +111,8 @@ async fn present_milestone_overview(
 
     milestone_issues.sort();
 
-    let mut table = ctx.make_table();
-
-    table
+    let mut table = ctx
+        .make_table()
         .set_header(vec![format!(
             "Milestone #{}",
             option_display(&milestone.id)
@@ -120,13 +128,13 @@ async fn present_milestone_overview(
         ]);
 
     if !milestone_issues.is_empty() {
-        table.add_row(vec![
+        table = table.add_row(vec![
             String::from("Related Issues"),
             milestone_issues.join(", "),
         ]);
     }
 
-    table
+    table = table
         .add_row(vec![
             String::from("Due On"),
             option_display(&milestone.due_on.as_ref().map(render_datetime_regular)),
