@@ -1,10 +1,11 @@
 use crate::render::json::JsonToStdout;
 use crate::types::context::BergContext;
 use crate::types::output::OutputMode;
-use crate::{actions::GeneralArgs, render::option::option_display};
+use crate::{actions::GlobalArgs, render::option::option_display};
 use forgejo_api::structs::{NotificationThread, NotifyGetListQuery};
 
 use clap::Parser;
+use miette::IntoDiagnostic;
 
 #[derive(Debug, Parser)]
 pub struct ListNotificationArgs {
@@ -34,17 +35,18 @@ pub struct ListNotificationArgs {
 }
 
 impl ListNotificationArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
 
         let (_, notification_threads_list) = ctx
             .client
             .notify_get_list(NotifyGetListQuery {
                 ..Default::default()
             })
-            .await?;
+            .await
+            .into_diagnostic()?;
 
-        match general_args.output_mode {
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => {
                 tracing::debug!("{notification_threads_list:?}");
                 present_notification_threads(&ctx, notification_threads_list);
@@ -66,22 +68,18 @@ fn present_notification_threads(
         "Notification Threads"
     };
 
-    let mut table = ctx.make_table();
-
-    table
-        .set_header(vec![header])
-        .add_rows(
-            notification_threads_list
-                .into_iter()
-                .map(|notification_thread| {
-                    vec![option_display(
-                        &notification_thread
-                            .subject
-                            .as_ref()
-                            .and_then(|subject| subject.title.as_ref()),
-                    )]
-                }),
-        );
+    let table = ctx.make_table().set_header(vec![header]).add_rows(
+        notification_threads_list
+            .into_iter()
+            .map(|notification_thread| {
+                vec![option_display(
+                    &notification_thread
+                        .subject
+                        .as_ref()
+                        .and_then(|subject| subject.title.as_ref()),
+                )]
+            }),
+    );
 
     println!("{table}", table = table.show());
 }
