@@ -3,7 +3,7 @@ pub mod view;
 
 use clap::Subcommand;
 
-use super::GeneralArgs;
+use super::GlobalArgs;
 
 /// Notification subcommands
 #[derive(Debug, Subcommand)]
@@ -13,10 +13,10 @@ pub enum NotificationArgs {
 }
 
 impl NotificationArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
         match self {
-            NotificationArgs::List(args) => args.run(general_args).await,
-            NotificationArgs::View(args) => args.run(general_args).await,
+            NotificationArgs::List(args) => args.run(global_args).await,
+            NotificationArgs::View(args) => args.run(global_args).await,
         }
     }
 }
