@@ -3,9 +3,9 @@ use crate::render::option::{option_debug_display, option_display};
 use crate::render::ui::fuzzy_select_with_key;
 use crate::types::context::BergContext;
 use crate::types::output::OutputMode;
-use crate::{actions::GeneralArgs, render::datetime::render_datetime_and_info};
-use anyhow::Context;
+use crate::{actions::GlobalArgs, render::datetime::render_datetime_and_info};
 use forgejo_api::structs::{NotificationThread, NotifyGetListQuery};
+use miette::{Context, IntoDiagnostic};
 
 use clap::Parser;
 #[derive(Debug, Parser)]
@@ -19,8 +19,8 @@ pub struct ViewNotificationArgs {
 }
 
 impl ViewNotificationArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
 
         let thread_id = if let Some(id) = ctx.args.id {
             id
@@ -30,7 +30,8 @@ impl ViewNotificationArgs {
                 .notify_get_list(NotifyGetListQuery {
                     ..Default::default()
                 })
-                .await?;
+                .await
+                .into_diagnostic()?;
             fuzzy_select_with_key(
                 &notification_threads
                     .iter()
@@ -51,10 +52,11 @@ impl ViewNotificationArgs {
 
         let selected_notification_thread = ctx
             .client
-            .notify_get_thread(thread_id.to_string().as_str())
-            .await?;
+            .notify_get_thread(thread_id)
+            .await
+            .into_diagnostic()?;
 
-        match general_args.output_mode {
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => {
                 present_notification_thread_details(&ctx, selected_notification_thread);
             }
@@ -69,9 +71,8 @@ fn present_notification_thread_details(
     ctx: &BergContext<ViewNotificationArgs>,
     notification_thread: NotificationThread,
 ) {
-    let mut table = ctx.make_table();
-
-    table
+    let table = ctx
+        .make_table()
         .add_row(vec![
             String::from("Title"),
             option_display(
@@ -96,7 +97,8 @@ fn present_notification_thread_details(
                 &notification_thread
                     .subject
                     .as_ref()
-                    .and_then(|subject| subject.r#type.as_ref()),
+                    .and_then(|subject| subject.r#type)
+                    .and_then(|subject| serde_json::to_string(&subject).ok()),
             ),
         ])
         .add_row(vec![
