@@ -6,18 +6,18 @@ use crate::render::spinner::spin_until_ready;
 use crate::render::ui::fuzzy_select_with_key;
 use crate::types::context::BergContext;
 use crate::types::git::OwnerRepo;
-use crate::{actions::GeneralArgs, types::output::OutputMode};
-use anyhow::Context;
+use crate::{actions::GlobalArgs, types::output::OutputMode};
 use clap::Parser;
 use forgejo_api::structs::{CreateIssueCommentOption, PullRequest, RepoListPullRequestsQuery};
+use miette::{Context, IntoDiagnostic};
 
 /// Add comment to selected pull request
 #[derive(Parser, Debug)]
 pub struct CommentPullRequestArgs {}
 
 impl CommentPullRequestArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
 
         let OwnerRepo { owner, repo } = ctx.owner_repo()?;
         let pull_request = select_pull_request(&ctx).await?;
@@ -29,15 +29,11 @@ impl CommentPullRequestArgs {
 
         let comment = ctx
             .client
-            .issue_create_comment(
-                owner.as_str(),
-                repo.as_str(),
-                pull_request_id as u64,
-                options,
-            )
-            .await?;
+            .issue_create_comment(owner.as_str(), repo.as_str(), pull_request_id, options)
+            .await
+            .into_diagnostic()?;
 
-        match general_args.output_mode {
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => {
                 tracing::debug!("{comment:?}");
             }
@@ -51,7 +47,7 @@ impl CommentPullRequestArgs {
 async fn create_options(
     ctx: &BergContext<CommentPullRequestArgs>,
     pull_request: &PullRequest,
-) -> anyhow::Result<CreateIssueCommentOption> {
+) -> miette::Result<CreateIssueCommentOption> {
     let body = ctx.editor_for(
         "a comment",
         format!(
@@ -69,14 +65,19 @@ async fn create_options(
 
 async fn select_pull_request(
     ctx: &BergContext<CommentPullRequestArgs>,
-) -> anyhow::Result<PullRequest> {
+) -> miette::Result<PullRequest> {
     let OwnerRepo { owner, repo } = ctx.owner_repo()?;
-    let (_, pull_requests_list) = spin_until_ready(ctx.client.repo_list_pull_requests(
-        owner.as_str(),
-        repo.as_str(),
-        RepoListPullRequestsQuery::default(),
-    ))
-    .await?;
+    let (_, pull_requests_list) = spin_until_ready(
+        ctx.client
+            .repo_list_pull_requests(
+                owner.as_str(),
+                repo.as_str(),
+                RepoListPullRequestsQuery::default(),
+            )
+            .send(),
+    )
+    .await
+    .into_diagnostic()?;
 
     fuzzy_select_with_key(
         &pull_requests_list,
