@@ -1,4 +1,4 @@
-use crate::actions::GeneralArgs;
+use crate::actions::GlobalArgs;
 use crate::actions::text_manipulation::{input_prompt_for, select_prompt_for};
 use crate::render::json::JsonToStdout;
 use crate::render::option::option_display;
@@ -8,12 +8,11 @@ use crate::render::ui::{
 use crate::types::context::BergContext;
 use crate::types::git::OwnerRepo;
 use crate::types::output::OutputMode;
-use anyhow::Context;
 use clap::Parser;
 use forgejo_api::structs::{
     CreatePullRequestOption, IssueGetMilestonesListQuery, IssueListLabelsQuery,
-    RepoListBranchesQuery,
 };
+use miette::{Context, IntoDiagnostic};
 use strum::{Display, VariantArray};
 
 /// Create a pull request
@@ -60,19 +59,26 @@ enum CreatableFields {
 }
 
 impl CreatePullRequestArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
 
         let OwnerRepo { repo, owner } = ctx.owner_repo()?;
         let options = create_options(&ctx).await?;
         let pull_request = ctx
             .client
             .repo_create_pull_request(owner.as_str(), repo.as_str(), options)
-            .await?;
+            .await
+            .into_diagnostic()?;
 
-        match general_args.output_mode {
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => {
-                tracing::debug!("{pull_request:?}");
+                println!(
+                    "Successfully created pull request!{opt_url}",
+                    opt_url = pull_request
+                        .url
+                        .map(|url| format!("\n\n\tSee: {url}"))
+                        .unwrap_or_default()
+                );
             }
             OutputMode::Json => pull_request.print_json()?,
         }
@@ -83,15 +89,30 @@ impl CreatePullRequestArgs {
 
 async fn create_options(
     ctx: &BergContext<CreatePullRequestArgs>,
-) -> anyhow::Result<CreatePullRequestOption> {
+) -> miette::Result<CreatePullRequestOption> {
+    let OwnerRepo { owner, repo } = ctx.owner_repo()?;
     let title = match ctx.args.title.as_ref() {
         Some(title) => title.clone(),
-        None => inquire::Text::new(input_prompt_for("Pull Request Title").as_str()).prompt()?,
+        None => {
+            if ctx.global_args.non_interactive {
+                miette::bail!(
+                    "You have to specify the pull request title in non-interactive mode!"
+                );
+            }
+            inquire::Text::new(input_prompt_for("Pull Request Title").as_str())
+                .prompt()
+                .into_diagnostic()?
+        }
     };
 
     let target_branch = match ctx.args.target_branch.as_ref() {
         Some(branch) => branch.clone(),
         None => {
+            if ctx.global_args.non_interactive {
+                miette::bail!(
+                    "You have to specify the pull request target branch in non-interactive mode!"
+                );
+            }
             select_branch(
                 ctx,
                 "target branch into which changes are merged",
@@ -106,59 +127,112 @@ async fn create_options(
         Some(branch) => branch.clone(),
         None => {
             let current_checkout = get_current_checkout()?;
-            select_branch(
-                ctx,
-                "source branch containing the changes",
-                vec![current_checkout.as_str()],
-                Some(target_branch.as_str()),
-            )
-            .await?
+            if ctx.global_args.non_interactive {
+                current_checkout
+            } else {
+                select_branch(
+                    ctx,
+                    "source branch containing the changes",
+                    vec![current_checkout.as_str()],
+                    Some(target_branch.as_str()),
+                )
+                .await?
+            }
         }
     };
 
+    let labels = if let Some(requested_labels) = ctx.args.labels.as_ref() {
+        let (_, issue_labels) = ctx
+            .client
+            .issue_list_labels(owner.as_str(), repo.as_str(), Default::default())
+            .await
+            .into_diagnostic()?;
+        let labels = requested_labels
+            .iter()
+            .map(|label_name| {
+                issue_labels
+                    .iter()
+                    .find(|label| label.name.as_ref().is_some_and(|name| name == label_name))
+                    .with_context(|| format!("Label with name {label_name} doesn't exist yet"))
+                    .context("Please create all labels before using them")?
+                    .id
+                    .context("Selected label is missing an ID")
+            })
+            .collect::<Result<Vec<_>, _>>()?;
+        Some(labels)
+    } else {
+        None
+    };
+
+    let milestone = if let Some(milestone_title) = ctx.args.milestone.as_ref() {
+        let (_, milestones) = ctx
+            .client
+            .issue_get_milestones_list(owner.as_str(), repo.as_str(), Default::default())
+            .await
+            .into_diagnostic()?;
+        let selected_milestone = milestones
+            .into_iter()
+            .find(|milestone| {
+                milestone
+                    .title
+                    .as_ref()
+                    .is_some_and(|title| title == milestone_title)
+            })
+            .with_context(|| format!("Couldn't find milestone with title: {milestone_title}"))?;
+        Some(
+            selected_milestone
+                .id
+                .context("Milestone is expected to have a milestone ID!")?,
+        )
+    } else {
+        None
+    };
+
     let mut options = CreatePullRequestOption {
         title: Some(title),
         base: Some(target_branch),
         head: Some(source_branch),
         assignee: None,
-        assignees: None,
-        body: None,
+        assignees: ctx.args.assignees.clone(),
+        body: ctx.args.body.clone(),
         due_date: None,
-        labels: None,
-        milestone: None,
+        labels,
+        milestone,
     };
 
-    let optional_data = {
-        use CreatableFields::*;
-        [
-            (Labels, ctx.args.labels.is_none()),
-            (Assignees, ctx.args.assignees.is_none()),
-            (Milestone, ctx.args.milestone.is_none()),
-        ]
-        .into_iter()
-        .filter_map(|(name, missing)| missing.then_some(name))
-        .collect::<Vec<_>>()
-    };
+    if !ctx.global_args.non_interactive {
+        let optional_data = {
+            use CreatableFields::*;
+            [
+                (Labels, ctx.args.labels.is_none()),
+                (Assignees, ctx.args.assignees.is_none()),
+                (Milestone, ctx.args.milestone.is_none()),
+            ]
+            .into_iter()
+            .filter_map(|(name, missing)| missing.then_some(name))
+            .collect::<Vec<_>>()
+        };
 
-    let chosen_optionals = multi_fuzzy_select_with_key(
-        &optional_data,
-        "Choose optional properties",
-        |_| false,
-        |o| o.to_string(),
-    )?;
+        let chosen_optionals = multi_fuzzy_select_with_key(
+            &optional_data,
+            "Choose optional properties",
+            |_| false,
+            |o| o.to_string(),
+        )?;
 
-    options.body.replace(pr_body(ctx)?);
-    {
-        use CreatableFields::*;
-        options.labels = pr_labels(ctx, chosen_optionals.contains(&&Labels)).await?;
-        options.assignees = pr_assignees(ctx, chosen_optionals.contains(&&Assignees)).await?;
-        options.milestone = pr_milestone(ctx, chosen_optionals.contains(&&Milestone)).await?;
+        options.body.replace(pr_body(ctx)?);
+        {
+            use CreatableFields::*;
+            options.labels = pr_labels(ctx, chosen_optionals.contains(&&Labels)).await?;
+            options.assignees = pr_assignees(ctx, chosen_optionals.contains(&&Assignees)).await?;
+            options.milestone = pr_milestone(ctx, chosen_optionals.contains(&&Milestone)).await?;
+        }
     }
 
     Ok(options)
 }
 
-fn pr_body(ctx: &BergContext<CreatePullRequestArgs>) -> anyhow::Result<String> {
+fn pr_body(ctx: &BergContext<CreatePullRequestArgs>) -> miette::Result<String> {
     let body = match ctx.args.body.as_ref() {
         Some(body) => body.clone(),
         None => ctx.editor_for("a description", "Enter a pull request description")?,
@@ -169,7 +243,7 @@ fn pr_body(ctx: &BergContext<CreatePullRequestArgs>) -> anyhow::Result<String> {
 async fn pr_labels(
     ctx: &BergContext<CreatePullRequestArgs>,
     interactive: bool,
-) -> anyhow::Result<Option<Vec<i64>>> {
+) -> miette::Result<Option<Vec<i64>>> {
     let OwnerRepo { repo, owner } = ctx.owner_repo()?;
 
     let (_, all_labels) = ctx
@@ -179,7 +253,8 @@ async fn pr_labels(
             repo.as_str(),
             IssueListLabelsQuery::default(),
         )
-        .await?;
+        .await
+        .into_diagnostic()?;
 
     let labels = match &ctx.args.labels {
         Some(label_names) => {
@@ -225,13 +300,14 @@ async fn pr_labels(
 async fn pr_assignees(
     ctx: &BergContext<CreatePullRequestArgs>,
     interactive: bool,
-) -> anyhow::Result<Option<Vec<String>>> {
+) -> miette::Result<Option<Vec<String>>> {
     let OwnerRepo { repo, owner } = ctx.owner_repo()?;
 
     let (_, all_assignees) = ctx
         .client
         .repo_get_assignees(owner.as_str(), repo.as_str())
-        .await?;
+        .await
+        .into_diagnostic()?;
     let assignees = match &ctx.args.assignees {
         Some(assignees_names) => Some(assignees_names.clone()),
         None => {
@@ -266,7 +342,7 @@ async fn pr_assignees(
 async fn pr_milestone(
     ctx: &BergContext<CreatePullRequestArgs>,
     interactive: bool,
-) -> anyhow::Result<Option<i64>> {
+) -> miette::Result<Option<i64>> {
     let OwnerRepo { repo, owner } = ctx.owner_repo()?;
 
     let (_, all_milestones) = ctx
@@ -276,7 +352,8 @@ async fn pr_milestone(
             repo.as_str(),
             IssueGetMilestonesListQuery::default(),
         )
-        .await?;
+        .await
+        .into_diagnostic()?;
 
     let milestone = match &ctx.args.milestone {
         Some(milestone_name) => Some(
@@ -316,16 +393,13 @@ async fn select_branch(
     prompt_text: &str,
     default_branch_names: Vec<&str>,
     filter_branch: Option<&str>,
-) -> anyhow::Result<String> {
+) -> miette::Result<String> {
     let OwnerRepo { repo, owner } = ctx.owner_repo()?;
     let (_, branches_list) = ctx
         .client
-        .repo_list_branches(
-            owner.as_str(),
-            repo.as_str(),
-            RepoListBranchesQuery::default(),
-        )
-        .await?;
+        .repo_list_branches(owner.as_str(), repo.as_str())
+        .await
+        .into_diagnostic()?;
     let branches = branches_list
         .into_iter()
         .filter(|branch| {
@@ -338,11 +412,11 @@ async fn select_branch(
 
     if branches.is_empty() {
         if filter_branch.is_some() {
-            anyhow::bail!(
+            miette::bail!(
                 "No remote branches except {filter_branch:?} found. Maybe the branch you want to merge doesn't exist on remote yet?"
             );
         } else {
-            anyhow::bail!("No remote branches found.");
+            miette::bail!("No remote branches found.");
         }
     }
 
@@ -364,12 +438,13 @@ async fn select_branch(
     .map(|branch| option_display(&branch.name))
 }
 
-fn get_current_checkout() -> anyhow::Result<String> {
+fn get_current_checkout() -> miette::Result<String> {
     let output = std::process::Command::new("git")
         .arg("branch")
         .arg("--show-current")
-        .output()?;
+        .output()
+        .into_diagnostic()?;
     String::from_utf8(output.stdout)
         .map(|base| base.trim().to_owned())
-        .map_err(anyhow::Error::from)
+        .into_diagnostic()
 }
