@@ -1,15 +1,15 @@
-use crate::actions::GeneralArgs;
+use crate::actions::GlobalArgs;
 use crate::render::json::JsonToStdout;
 use crate::render::option::option_display;
 use crate::render::spinner::spin_until_ready;
-use crate::render::ui::{fuzzy_select_with_key, multi_fuzzy_select_with_key};
+use crate::render::ui::{fuzzy_select_with_key, multi_fuzzy_select_with_key, select_state};
 use crate::types::context::BergContext;
 use crate::types::git::OwnerRepo;
 use crate::types::output::OutputMode;
-use anyhow::Context;
 use forgejo_api::structs::{
-    EditPullRequestOption, IssueListLabelsQuery, PullRequest, RepoListPullRequestsQuery, StateType,
+    EditPullRequestOption, IssueListLabelsQuery, PullRequest, RepoListPullRequestsQuery,
 };
+use miette::{Context, IntoDiagnostic};
 use strum::{Display, VariantArray};
 
 use crate::actions::text_manipulation::{input_prompt_for, select_prompt_for};
@@ -32,8 +32,8 @@ enum EditableFields {
 }
 
 impl EditPullRequestArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
 
         let OwnerRepo { repo, owner } = ctx.owner_repo()?;
         let pull_request = select_pull_request(&ctx).await?;
@@ -49,15 +49,11 @@ impl EditPullRequestArgs {
 
         let updated_pull_request = ctx
             .client
-            .repo_edit_pull_request(
-                owner.as_str(),
-                repo.as_str(),
-                pull_request_id as u64,
-                options,
-            )
-            .await?;
+            .repo_edit_pull_request(owner.as_str(), repo.as_str(), pull_request_id, options)
+            .await
+            .into_diagnostic()?;
 
-        match general_args.output_mode {
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => {
                 tracing::debug!("{updated_pull_request:?}");
             }
@@ -70,14 +66,19 @@ impl EditPullRequestArgs {
 
 async fn select_pull_request(
     ctx: &BergContext<EditPullRequestArgs>,
-) -> anyhow::Result<PullRequest> {
+) -> miette::Result<PullRequest> {
     let OwnerRepo { repo, owner } = ctx.owner_repo()?;
-    let (_, pull_requests_list) = spin_until_ready(ctx.client.repo_list_pull_requests(
-        owner.as_str(),
-        repo.as_str(),
-        RepoListPullRequestsQuery::default(),
-    ))
-    .await?;
+    let (_, pull_requests_list) = spin_until_ready(
+        ctx.client
+            .repo_list_pull_requests(
+                owner.as_str(),
+                repo.as_str(),
+                RepoListPullRequestsQuery::default(),
+            )
+            .send(),
+    )
+    .await
+    .into_diagnostic()?;
 
     fuzzy_select_with_key(
         &pull_requests_list,
@@ -90,7 +91,7 @@ async fn select_pull_request(
 async fn create_options(
     ctx: &BergContext<EditPullRequestArgs>,
     pull_request: &PullRequest,
-) -> anyhow::Result<EditPullRequestOption> {
+) -> miette::Result<EditPullRequestOption> {
     let selected_update_fields = multi_fuzzy_select_with_key(
         EditableFields::VARIANTS,
         select_prompt_for("options"),
@@ -127,9 +128,7 @@ async fn create_options(
             .replace(pull_request_description(ctx, pull_request.body.clone()).await?);
     }
     if selected_update_fields.contains(&&EditableFields::State) {
-        options
-            .state
-            .replace(pull_request_state(ctx, pull_request.state)?);
+        options.state.replace(select_state(pull_request.state)?);
     }
     if selected_update_fields.contains(&&EditableFields::Title) {
         options
@@ -154,13 +153,14 @@ async fn create_options(
 async fn pull_request_assignees(
     ctx: &BergContext<EditPullRequestArgs>,
     current_assignees: Option<Vec<i64>>,
-) -> anyhow::Result<Vec<String>> {
+) -> miette::Result<Vec<String>> {
     let OwnerRepo { repo, owner } = ctx.owner_repo()?;
     let current_assignees = current_assignees.unwrap_or_default();
     let (_, all_assignees) = ctx
         .client
         .repo_get_assignees(owner.as_str(), repo.as_str())
-        .await?;
+        .await
+        .into_diagnostic()?;
     let selected_assignees = multi_fuzzy_select_with_key(
         &all_assignees,
         select_prompt_for("assignees"),
@@ -177,7 +177,7 @@ async fn pull_request_assignees(
 async fn pull_request_description(
     ctx: &BergContext<EditPullRequestArgs>,
     current_description: Option<String>,
-) -> anyhow::Result<String> {
+) -> miette::Result<String> {
     ctx.editor_for(
         "a description",
         current_description
@@ -186,22 +186,10 @@ async fn pull_request_description(
     )
 }
 
-fn pull_request_state(
-    _ctx: &BergContext<EditPullRequestArgs>,
-    _current_state: Option<StateType>,
-) -> anyhow::Result<String> {
-    let selected_state = fuzzy_select_with_key(
-        &[StateType::Open, StateType::Closed],
-        select_prompt_for("states"),
-        |f| format!("{f:?}"),
-    )?;
-    Ok(format!("{selected_state:?}"))
-}
-
 async fn pull_request_title(
     _ctx: &BergContext<EditPullRequestArgs>,
     current_title: Option<String>,
-) -> anyhow::Result<String> {
+) -> miette::Result<String> {
     inquire::Text::new(input_prompt_for("Choose a new pull request title").as_str())
         .with_default(
             current_title
@@ -209,13 +197,13 @@ async fn pull_request_title(
                 .unwrap_or("Enter pull request title"),
         )
         .prompt()
-        .map_err(anyhow::Error::from)
+        .into_diagnostic()
 }
 
 async fn pull_request_labels(
     ctx: &BergContext<EditPullRequestArgs>,
     current_labels: Option<Vec<i64>>,
-) -> anyhow::Result<Vec<i64>> {
+) -> miette::Result<Vec<i64>> {
     let OwnerRepo { repo, owner } = ctx.owner_repo()?;
     let current_labels = current_labels.unwrap_or_default();
     let (_, all_labels) = ctx
@@ -225,7 +213,8 @@ async fn pull_request_labels(
             repo.as_str(),
             IssueListLabelsQuery::default(),
         )
-        .await?;
+        .await
+        .into_diagnostic()?;
 
     let selected_labels = multi_fuzzy_select_with_key(
         &all_labels,
