@@ -2,8 +2,9 @@ use forgejo_api::structs::{
     PullRequest, RepoListPullRequestsQuery, RepoListPullRequestsQueryState,
 };
 use itertools::Itertools;
+use miette::IntoDiagnostic;
 
-use crate::actions::GeneralArgs;
+use crate::actions::GlobalArgs;
 use crate::render::json::JsonToStdout;
 use crate::render::option::{option_debug_display, option_display};
 use crate::render::spinner::spin_until_ready;
@@ -17,12 +18,8 @@ use crate::types::output::OutputMode;
 use clap::Parser;
 
 /// List pull requests
-#[derive(Parser, Debug, Clone, Copy)]
+#[derive(Parser, Debug, Clone)]
 pub struct ListPullRequestArgs {
-    /// Number of pull requests to be displayed
-    #[arg(short, long, value_name = "N", default_value_t = 5)]
-    pub count: u32,
-
     /// Sort using a certain criteria
     #[arg(long, default_value_t = pr_query_sort::PullRequestsQuerySort::Recentupdate)]
     pub sort: PullRequestsQuerySort,
@@ -33,9 +30,7 @@ pub struct ListPullRequestArgs {
 }
 
 impl ListPullRequestArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
-
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
         let state = match self.state {
             ViewStateType::All => RepoListPullRequestsQueryState::All,
             ViewStateType::Closed => RepoListPullRequestsQueryState::Closed,
@@ -44,19 +39,21 @@ impl ListPullRequestArgs {
         let query = RepoListPullRequestsQuery {
             state: Some(state),
             sort: Some(self.sort.into()),
-            limit: Some(self.count),
             ..Default::default()
         };
 
-        let OwnerRepo { repo, owner } = ctx.owner_repo()?;
-        let (_, pull_requests_list) = spin_until_ready(ctx.client.repo_list_pull_requests(
-            owner.as_str(),
-            repo.as_str(),
-            query,
-        ))
-        .await?;
+        let ctx = BergContext::new(self, global_args).await?;
 
-        match general_args.output_mode {
+        let OwnerRepo { repo, owner } = ctx.owner_repo()?;
+        let (_, pull_requests_list) = spin_until_ready(
+            ctx.client
+                .repo_list_pull_requests(owner.as_str(), repo.as_str(), query)
+                .send(),
+        )
+        .await
+        .into_diagnostic()?;
+
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => {
                 present_pull_requests_list(&ctx, pull_requests_list);
             }
@@ -73,48 +70,46 @@ fn present_pull_requests_list(
 ) {
     let pull_requests_empty = pull_requests.is_empty();
 
-    let mut table = ctx.make_table().add_table((!pull_requests_empty).then(|| {
-        let mut inner_table = ctx.make_table();
-
-        inner_table
-            .set_header(vec!["Number", "Status", "Name", "Labels"])
-            .add_rows(pull_requests.iter().map(|issue| {
-                let PullRequest {
-                    title,
-                    number,
-                    labels,
-                    state,
-                    ..
-                } = issue;
-                let labels = option_display(&labels.as_ref().map(|labels| {
-                    if labels.is_empty() {
-                        String::from("x")
-                    } else {
-                        labels
-                            .iter()
-                            .filter_map(|label| label.name.as_ref())
-                            .join(",")
-                    }
-                }));
-                vec![
-                    option_display(number),
-                    option_debug_display(state),
-                    option_display(title),
-                    labels,
-                ]
+    let table = ctx
+        .make_table()
+        .set_header(vec!["Number", "Status", "Name", "Labels"])
+        .add_rows(pull_requests.iter().map(|issue| {
+            let PullRequest {
+                title,
+                number,
+                labels,
+                state,
+                ..
+            } = issue;
+            let labels = option_display(&labels.as_ref().map(|labels| {
+                if labels.is_empty() {
+                    String::from("x")
+                } else {
+                    labels
+                        .iter()
+                        .filter_map(|label| label.name.as_ref())
+                        .join(",")
+                }
             }));
+            vec![
+                option_display(number),
+                option_debug_display(state),
+                option_display(title),
+                labels,
+            ]
+        }));
 
-        inner_table
-    }));
-
-    table.set_header(vec![format!(
+    let header = format!(
         "Pull Requests {}",
         if pull_requests_empty {
             " (empty)"
         } else {
             Default::default()
         }
-    )]);
+    );
 
-    println!("{table}", table = table.show());
+    let underscore = "=".repeat(header.len());
+    let out = [header, underscore, table.show()].join("\n");
+
+    println!("{out}");
 }
