@@ -8,7 +8,7 @@ pub mod view;
 
 use clap::Subcommand;
 
-use super::GeneralArgs;
+use super::GlobalArgs;
 
 /// Pull request subcommands
 #[derive(Subcommand, Debug)]
@@ -21,13 +21,13 @@ pub enum PullRequestArgs {
 }
 
 impl PullRequestArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
         match self {
-            PullRequestArgs::List(args) => args.run(general_args).await,
-            PullRequestArgs::Create(args) => args.run(general_args).await,
-            PullRequestArgs::Edit(args) => args.run(general_args).await,
-            PullRequestArgs::View(args) => args.run(general_args).await,
-            PullRequestArgs::Comment(args) => args.run(general_args).await,
+            PullRequestArgs::List(args) => args.run(global_args).await,
+            PullRequestArgs::Create(args) => args.run(global_args).await,
+            PullRequestArgs::Edit(args) => args.run(global_args).await,
+            PullRequestArgs::View(args) => args.run(global_args).await,
+            PullRequestArgs::Comment(args) => args.run(global_args).await,
         }
     }
 }
