@@ -1,5 +1,5 @@
 use super::display_pull_request;
-use crate::actions::{GeneralArgs, text_manipulation::select_prompt_for};
+use crate::actions::{GlobalArgs, text_manipulation::select_prompt_for};
 use crate::render::comment::render_comment;
 use crate::render::datetime::render_datetime_and_info;
 use crate::render::json::JsonToStdout;
@@ -10,16 +10,19 @@ use crate::types::api::state_type::ViewStateType;
 use crate::types::context::BergContext;
 use crate::types::git::OwnerRepo;
 use crate::types::output::OutputMode;
-use anyhow::Context;
 use clap::Parser;
 use forgejo_api::structs::{
     IssueGetCommentsQuery, PullRequest, RepoListPullRequestsQuery, RepoListPullRequestsQueryState,
 };
 use itertools::Itertools;
+use miette::{Context, IntoDiagnostic};
 
 #[derive(Parser, Debug)]
 #[command(about = "View details of a selected pull request")]
 pub struct ViewPullRequestsArgs {
+    /// Optionally, specify a selected issue in the command line
+    pub index: Option<i64>,
+
     /// Select from pull requests with the chosen state
     #[arg(
         short,
@@ -35,8 +38,8 @@ pub struct ViewPullRequestsArgs {
 }
 
 impl ViewPullRequestsArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
 
         let OwnerRepo { repo, owner } = ctx.owner_repo()?;
         let state = match ctx.args.state {
@@ -44,31 +47,51 @@ impl ViewPullRequestsArgs {
             ViewStateType::Open => RepoListPullRequestsQueryState::Open,
             ViewStateType::All => RepoListPullRequestsQueryState::All,
         };
-        let (_, pull_requests_list) = spin_until_ready(ctx.client.repo_list_pull_requests(
-            owner.as_str(),
-            repo.as_str(),
-            RepoListPullRequestsQuery {
-                state: Some(state),
-                ..Default::default()
-            },
-        ))
-        .await?;
 
-        let pull_request = fuzzy_select_with_key(
-            &pull_requests_list,
-            select_prompt_for("pull request"),
-            display_pull_request,
-        )?;
+        let selected_pull_requst = if let Some(index) = ctx.args.index {
+            ctx.client
+                .repo_get_pull_request(owner.as_str(), repo.as_str(), index)
+                .await
+                .into_diagnostic()?
+        } else {
+            if ctx.global_args.non_interactive {
+                miette::bail!(
+                    "non-interactive mode enabled. You have to specify an pull requests #number"
+                );
+            };
+            let (_, pull_requests_list) = spin_until_ready(
+                ctx.client
+                    .repo_list_pull_requests(
+                        owner.as_str(),
+                        repo.as_str(),
+                        RepoListPullRequestsQuery {
+                            state: Some(state),
+                            ..Default::default()
+                        },
+                    )
+                    .send(),
+            )
+            .await
+            .into_diagnostic()?;
 
-        match general_args.output_mode {
+            fuzzy_select_with_key(
+                &pull_requests_list,
+                select_prompt_for("pull request"),
+                display_pull_request,
+            )
+            .cloned()?
+        };
+
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => {
                 if ctx.args.comments {
-                    spin_until_ready(present_pull_request_comments(&ctx, pull_request)).await?;
+                    spin_until_ready(present_pull_request_comments(&ctx, &selected_pull_requst))
+                        .await?;
                 } else {
-                    present_pull_request_overview(&ctx, pull_request);
+                    present_pull_request_overview(&ctx, &selected_pull_requst);
                 }
             }
-            OutputMode::Json => pull_request.print_json()?,
+            OutputMode::Json => selected_pull_requst.print_json()?,
         }
 
         Ok(())
@@ -85,12 +108,11 @@ fn present_pull_request_overview(
         .map(render_datetime_and_info)
         .unwrap_or_else(|| String::from("?"));
 
-    let mut table = ctx.make_table();
-
-    table
+    let table = ctx
+        .make_table()
         .set_header(vec![format!(
             "Pull Request #{}",
-            option_display(&pull_request.id)
+            option_display(&pull_request.number)
         )])
         .add_row(vec![
             String::from("Title"),
@@ -117,21 +139,24 @@ fn present_pull_request_overview(
 async fn present_pull_request_comments(
     ctx: &BergContext<ViewPullRequestsArgs>,
     pull_request: &PullRequest,
-) -> anyhow::Result<()> {
+) -> miette::Result<()> {
     let OwnerRepo { repo, owner } = ctx.owner_repo()?;
-    let nr = pull_request.id.context("Selected pull request has no ID")?;
+    let nr = pull_request
+        .number
+        .context("Selected pull request has no ID")?;
     let (_, comments) = ctx
         .client
         .issue_get_comments(
             owner.as_str(),
             repo.as_str(),
-            nr as u64,
+            nr,
             IssueGetCommentsQuery::default(),
         )
-        .await?;
+        .await
+        .into_diagnostic()?;
     let header = format!(
         "Pull Request #{} {}",
-        option_display(&pull_request.id),
+        option_display(&pull_request.number),
         if comments.is_empty() {
             "(no comments)"
         } else {
@@ -139,17 +164,16 @@ async fn present_pull_request_comments(
         }
     );
 
-    let mut table = ctx.make_table();
-
-    table
-        .set_header(vec![header])
-        .add_rows(comments.into_iter().filter_map(|comment| {
-            let username = comment.user.as_ref()?.login.as_ref()?.as_str();
-            let creation_time = comment.created_at.as_ref()?;
-            let comment = comment.body.as_ref()?;
-            let comment = render_comment(&ctx.config, username, creation_time, comment);
-            Some(vec![comment])
-        }));
+    let table =
+        ctx.make_table()
+            .set_header(vec![header])
+            .add_rows(comments.into_iter().filter_map(|comment| {
+                let username = comment.user.as_ref()?.login.as_ref()?.as_str();
+                let creation_time = comment.created_at.as_ref()?;
+                let comment = comment.body.as_ref()?;
+                let comment = render_comment(username, creation_time, comment);
+                Some(vec![comment])
+            }));
 
     println!("{table}", table = table.show());
 
