@@ -3,7 +3,7 @@ pub mod list;
 
 use clap::Subcommand;
 
-use super::GeneralArgs;
+use super::GlobalArgs;
 
 /// Release subcommands
 #[derive(Subcommand, Debug)]
@@ -13,10 +13,10 @@ pub enum ReleaseArgs {
 }
 
 impl ReleaseArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
         match self {
-            ReleaseArgs::Create(args) => args.run(general_args).await,
-            ReleaseArgs::List(args) => args.run(general_args).await,
+            ReleaseArgs::Create(args) => args.run(global_args).await,
+            ReleaseArgs::List(args) => args.run(global_args).await,
         }
     }
 }
