@@ -1,12 +1,16 @@
-use crate::actions::GeneralArgs;
+use crate::actions::GlobalArgs;
+use crate::actions::repo::clone::RepoCloneArgs;
 use crate::actions::text_manipulation::{input_prompt_for, select_prompt_for};
 use crate::render::json::JsonToStdout;
 use crate::render::ui::{fuzzy_select_with_key, multi_fuzzy_select_with_key};
 use crate::types::api::privacy_type::Privacy;
 use crate::types::context::BergContext;
+use crate::types::git::{MaybeOwnerRepo, OwnerRepo};
 use crate::types::output::OutputMode;
 use clap::Parser;
 use forgejo_api::structs::CreateRepoOption;
+use forgejo_api::{ApiError, ApiErrorKind, ForgejoError};
+use miette::{Context, IntoDiagnostic};
 use strum::{Display, VariantArray};
 
 /// Create a new repository
@@ -31,6 +35,10 @@ pub struct RepoCreateArgs {
     /// Repository visibility
     #[arg(short, long, value_enum, value_name = "VISIBILITY")]
     pub private: Option<Privacy>,
+
+    /// Whether or not to clone the repo after creating it remotely
+    #[arg(short, long)]
+    pub and_clone: bool,
 }
 
 #[derive(Display, PartialEq, Eq, VariantArray)]
@@ -41,29 +49,79 @@ enum CreatableFields {
 }
 
 impl RepoCreateArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args.clone()).await?;
 
         let options = create_options(&ctx).await?;
-        let pull_request = if let Some(org) = ctx.args.org.as_ref() {
+        let repo = options.name.clone();
+        let repository = if let Some(org) = ctx.args.org.as_ref() {
             ctx.client.create_org_repo(org, options).await
         } else {
             ctx.client.create_current_user_repo(options).await
-        }?;
-        match general_args.output_mode {
+        }
+        .map_err(|e| match e {
+            ForgejoError::ApiError(ApiError {
+                kind: ApiErrorKind::Other(code),
+                ..
+            }) if code.as_u16() == 409 => {
+                miette::miette!("Repository with the same name already exists!, got: {e}")
+            }
+            _ => miette::miette!("{e}"),
+        })?;
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => {
-                tracing::debug!("{pull_request:?}");
+                tracing::debug!("{repository:?}");
+            }
+            OutputMode::Json => repository.print_json()?,
+        }
+
+        // optionally clone the repository if user wishes so
+        if ctx.args.and_clone {
+            let user = ctx
+                .args
+                .org
+                .or(ctx.client.user_get_current().await.into_diagnostic()?.login)
+                .wrap_err_with(|| {
+                    miette::miette!(
+                        help = "Check your user settings",
+                        help = "Check your forgejo instance or contact its admins",
+                        "Currently logged in user has no valid username, aborting!"
+                    )
+                })?;
+            let owner_repo = MaybeOwnerRepo::ExplicitOwner(OwnerRepo { owner: user, repo });
+            let ssh_clone = RepoCloneArgs {
+                owner_and_repo: owner_repo.clone(),
+                use_ssh: true,
+                destination: None,
+            }
+            .run(global_args.clone())
+            .await
+            .context("Cloning with ssh failed ... trying https as fallback");
+
+            if ssh_clone.is_err() {
+                RepoCloneArgs {
+                    owner_and_repo: owner_repo,
+                    use_ssh: false,
+                    destination: None,
+                }
+                .run(global_args)
+                .await
+                .wrap_err(miette::miette!(
+                    help = "This shouldn't happen. Please open an issue!",
+                    "Cloning via ssh and via https both failed!"
+                ))?;
             }
-            OutputMode::Json => pull_request.print_json()?,
         }
         Ok(())
     }
 }
 
-async fn create_options(ctx: &BergContext<RepoCreateArgs>) -> anyhow::Result<CreateRepoOption> {
+async fn create_options(ctx: &BergContext<RepoCreateArgs>) -> miette::Result<CreateRepoOption> {
     let name = match ctx.args.name.as_ref() {
         Some(name) => name.clone(),
-        None => inquire::Text::new(input_prompt_for("New Repository Name").as_str()).prompt()?,
+        None => inquire::Text::new(input_prompt_for("New Repository Name").as_str())
+            .prompt()
+            .into_diagnostic()?,
     };
 
     let mut options = CreateRepoOption {
@@ -96,7 +154,7 @@ async fn create_options(ctx: &BergContext<RepoCreateArgs>) -> anyhow::Result<Cre
         .collect::<Vec<_>>()
     };
 
-    if !optional_data.is_empty() && !ctx.general_args.non_interactive {
+    if !optional_data.is_empty() && !ctx.global_args.non_interactive {
         let chosen_optionals = multi_fuzzy_select_with_key(
             &optional_data,
             "Choose optional properties",
@@ -122,14 +180,16 @@ async fn create_options(ctx: &BergContext<RepoCreateArgs>) -> anyhow::Result<Cre
 fn repo_default_branch(
     ctx: &BergContext<RepoCreateArgs>,
     interactive: bool,
-) -> anyhow::Result<String> {
+) -> miette::Result<String> {
     let branch = match ctx.args.default_branch.as_ref() {
         Some(branch) => branch.clone(),
         None => {
             if !interactive {
                 return Ok(String::from("main"));
             }
-            inquire::Text::new(input_prompt_for("Default Branch Name").as_str()).prompt()?
+            inquire::Text::new(input_prompt_for("Default Branch Name").as_str())
+                .prompt()
+                .into_diagnostic()?
         }
     };
     Ok(branch)
@@ -138,7 +198,7 @@ fn repo_default_branch(
 async fn repo_private(
     ctx: &BergContext<RepoCreateArgs>,
     interactive: bool,
-) -> anyhow::Result<Option<bool>> {
+) -> miette::Result<Option<bool>> {
     let privacy = match ctx.args.private {
         Some(privacy) => match privacy {
             Privacy::Private => true,
@@ -168,7 +228,7 @@ async fn repo_private(
 async fn repo_description(
     ctx: &BergContext<RepoCreateArgs>,
     interactive: bool,
-) -> anyhow::Result<Option<String>> {
+) -> miette::Result<Option<String>> {
     let description = match ctx.args.description.as_ref() {
         Some(desc) => desc.clone(),
         None => {
