@@ -1,7 +1,7 @@
-use anyhow::Context;
 use forgejo_api::structs::Repository;
+use miette::{Context, IntoDiagnostic};
 
-use crate::actions::GeneralArgs;
+use crate::actions::GlobalArgs;
 use crate::render::json::JsonToStdout;
 use crate::render::option::option_display;
 use crate::render::spinner::spin_until_ready;
@@ -9,36 +9,23 @@ use crate::types::context::BergContext;
 use crate::types::git::OwnerRepo;
 use crate::types::output::OutputMode;
 
-use super::parse_owner_and_repo;
-
 use clap::Parser;
 
 /// Display short summary of the current repository
 #[derive(Parser, Debug)]
-pub struct RepoInfoArgs {
-    /// Repository to be queried for information, defaults to repo in $pwd if there is any
-    #[arg(value_name = "OWNER/REPO")]
-    pub owner_and_repo: Option<String>,
-}
+pub struct RepoInfoArgs {}
 
 impl RepoInfoArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
 
-        let (owner, repo) = ctx
-            .args
-            .owner_and_repo
-            .as_ref()
-            .and_then(|s| parse_owner_and_repo(s).ok())
-            .unwrap_or(
-                ctx.owner_repo()
-                    .map(|OwnerRepo { repo, owner }| (owner, repo))?,
-            );
-        let repo_data = spin_until_ready(ctx.client.repo_get(owner.as_str(), repo.as_str()))
+        let OwnerRepo { owner, repo } = ctx.owner_repo()?;
+        let repo_data = spin_until_ready(ctx.client.repo_get(owner.as_str(), repo.as_str()).send())
             .await
+            .into_diagnostic()
             .context("Current repo not found on this instance.")?;
 
-        match general_args.output_mode {
+        match ctx.global_args.output_mode {
             OutputMode::Pretty => {
                 present_repo_info(&ctx, repo_data);
             }
@@ -50,9 +37,8 @@ impl RepoInfoArgs {
 }
 
 fn present_repo_info(ctx: &BergContext<RepoInfoArgs>, repo_data: Repository) {
-    let mut table = ctx.make_table();
-
-    table
+    let table = ctx
+        .make_table()
         .set_header(vec!["Repository Info"])
         .add_row(vec![
             String::from("Repository Name"),
@@ -67,6 +53,14 @@ fn present_repo_info(ctx: &BergContext<RepoInfoArgs>, repo_data: Repository) {
                     .and_then(|user| user.login.as_ref()),
             ),
         ])
+        .add_row(vec![
+            String::from("Visibility"),
+            option_display(&repo_data.private.map(
+                |private| {
+                    if private { "Private" } else { "Public" }
+                },
+            )),
+        ])
         .add_row(vec![
             String::from("Stars"),
             format!("{}★", option_display(&repo_data.stars_count)),
