@@ -1,7 +1,8 @@
 use forgejo_api::structs::UserCurrentListReposQuery;
 use itertools::Itertools;
+use miette::IntoDiagnostic;
 
-use crate::actions::GeneralArgs;
+use crate::actions::GlobalArgs;
 use crate::render::json::JsonToStdout;
 use crate::render::option::option_display;
 use crate::render::spinner::spin_until_ready;
@@ -15,20 +16,23 @@ use clap::Parser;
 pub struct UserInfoArgs {}
 
 impl UserInfoArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let ctx = BergContext::new(self, general_args).await?;
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
+        let ctx = BergContext::new(self, global_args).await?;
 
         present_user_info(&ctx).await?;
         Ok(())
     }
 }
 
-async fn present_user_info(ctx: &BergContext<UserInfoArgs>) -> anyhow::Result<()> {
-    let user = spin_until_ready(ctx.client.user_get_current()).await?;
+async fn present_user_info(ctx: &BergContext<UserInfoArgs>) -> miette::Result<()> {
+    let user = spin_until_ready(ctx.client.user_get_current().send())
+        .await
+        .into_diagnostic()?;
     let (_, repos) = ctx
         .client
         .user_current_list_repos(UserCurrentListReposQuery::default())
-        .await?;
+        .await
+        .into_diagnostic()?;
     let top_repos = repos
         .iter()
         .sorted_by_key(|repo| repo.stars_count.unwrap_or_default())
@@ -36,11 +40,10 @@ async fn present_user_info(ctx: &BergContext<UserInfoArgs>) -> anyhow::Result<()
         .take(5)
         .collect::<Vec<_>>();
 
-    match ctx.general_args.output_mode {
+    match ctx.global_args.output_mode {
         OutputMode::Pretty => {
-            let mut table = ctx.make_table();
-
-            table
+            let table = ctx
+                .make_table()
                 .set_header(vec!["User Information"])
                 .add_row(vec![String::from("Username"), option_display(&user.login)])
                 .add_row(vec![
