@@ -2,7 +2,7 @@ pub mod info;
 
 use clap::Subcommand;
 
-use super::GeneralArgs;
+use super::GlobalArgs;
 
 /// User subcommands
 #[derive(Subcommand, Debug)]
@@ -11,9 +11,9 @@ pub enum UserArgs {
 }
 
 impl UserArgs {
-    pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
+    pub async fn run(self, global_args: GlobalArgs) -> miette::Result<()> {
         match self {
-            UserArgs::Info(args) => args.run(general_args).await,
+            UserArgs::Info(args) => args.run(global_args).await,
         }
     }
 }
