@@ -1,7 +1,7 @@
-use anyhow::Context;
+use miette::{Context, IntoDiagnostic};
 use std::path::PathBuf;
 
-pub fn berg_data_dir() -> anyhow::Result<PathBuf> {
+pub fn berg_data_dir() -> miette::Result<PathBuf> {
     let dir = dirs::data_dir().context("Couldn't find data directory for saving the token.")?;
 
     let data_dir = dir.join("berg-cli");
@@ -12,13 +12,14 @@ pub fn berg_data_dir() -> anyhow::Result<PathBuf> {
     let legacy_data_dir = dir.join(".berg-cli");
     if legacy_data_dir.exists() {
         std::fs::rename(legacy_data_dir, data_dir.as_path())
+            .into_diagnostic()
             .context("Failed to migrate config!")?;
     }
 
     Ok(data_dir)
 }
 
-pub fn berg_config_dir() -> anyhow::Result<PathBuf> {
+pub fn berg_config_dir() -> miette::Result<PathBuf> {
     let config_dir = dirs::config_dir()
         .context("Couldn't find config directory for saving global config")
         .map(|dir| dir.join("berg-cli"))?;
@@ -38,13 +39,15 @@ pub fn berg_config_dir() -> anyhow::Result<PathBuf> {
     Ok(config_dir)
 }
 
-pub fn token_path() -> anyhow::Result<PathBuf> {
+/// Tokens are saved per forgejo instance = per base url to allow users to use multiple instances
+/// smoothly without logging out inbetween
+pub fn token_path(instance: impl AsRef<str>) -> miette::Result<PathBuf> {
     berg_data_dir()
-        .map(|token_dir| token_dir.join("TOKEN"))
+        .map(|token_dir| token_dir.join(instance.as_ref()).join("TOKEN"))
         .context("token path not found")
 }
 
-pub fn config_path() -> anyhow::Result<PathBuf> {
+pub fn config_path() -> miette::Result<PathBuf> {
     berg_config_dir()
         .map(|dir| dir.join("berg.toml"))
         .context("config path not found")
