@@ -1,6 +1,6 @@
 use inquire::{Text, validator::Validation};
 
-pub fn mk_color_validator(prompt: Text) -> Text {
+pub fn mk_color_validator<'a>(prompt: Text<'a, 'a>) -> Text<'a, 'a> {
     prompt
         .with_help_message("(format: #xxxxxx)")
         .with_validator(|color: &str| {
