@@ -1,15 +1,6 @@
 use time::{OffsetDateTime, format_description};
 
-use crate::types::config::BergConfig;
-
-pub fn render_comment(
-    config: &BergConfig,
-    username: &str,
-    creation_time: &OffsetDateTime,
-    comment: &str,
-) -> String {
-    let mut table = config.make_table();
-
+pub fn render_comment(username: &str, creation_time: &OffsetDateTime, comment: &str) -> String {
     const PARENTHESES: usize = 2;
     const COLON: usize = 1;
 
@@ -20,13 +11,11 @@ pub fn render_comment(
         )
         .expect("Couldn't format DateTime'");
 
-    table.add_row(vec![comment]);
-
     format!(
         "{}\n({}):\n{}\n\n{}",
         username,
         creation_time_formatted,
         "=".repeat(creation_time_formatted.len() + PARENTHESES + COLON),
-        table.show()
+        comment
     )
 }
