@@ -1,4 +1,5 @@
 use chrono::Datelike;
+use miette::IntoDiagnostic;
 use time::{Date, OffsetDateTime, Time, format_description};
 
 pub fn render_datetime_and_info(datetime: &OffsetDateTime) -> String {
@@ -34,11 +35,14 @@ pub fn render_datetime_regular(datetime: &OffsetDateTime) -> String {
         .expect("Couldn't format DateTime'")
 }
 
-pub fn ask_datetime(prompt: &str) -> anyhow::Result<OffsetDateTime> {
-    let naive_date = inquire::DateSelect::new(prompt).prompt()?;
+pub fn ask_datetime(prompt: &str) -> miette::Result<OffsetDateTime> {
+    let naive_date = inquire::DateSelect::new(prompt)
+        .prompt()
+        .into_diagnostic()?;
 
     Ok(OffsetDateTime::new_utc(
-        Date::from_ordinal_date(naive_date.year(), naive_date.ordinal() as u16)?,
-        Time::from_hms(12, 0, 0)?,
+        Date::from_ordinal_date(naive_date.year(), naive_date.ordinal() as u16)
+            .into_diagnostic()?,
+        Time::from_hms(12, 0, 0).into_diagnostic()?,
     ))
 }
