@@ -1,4 +1,5 @@
-use anyhow::Context;
+use forgejo_api::structs::StateType;
+use miette::{Context, IntoDiagnostic};
 
 /// Given a list of `items`, this function allows the user to interactively select a subset of the
 /// given list.
@@ -13,7 +14,7 @@ pub fn multi_fuzzy_select_with_key<T>(
     prompt: impl AsRef<str>,
     is_selected: impl Fn(&T) -> bool,
     f_display: impl Fn(&T) -> String,
-) -> anyhow::Result<Vec<&T>> {
+) -> miette::Result<Vec<&T>> {
     // collect pre-selected items
     let already_selected = items
         .iter()
@@ -29,6 +30,7 @@ pub fn multi_fuzzy_select_with_key<T>(
     let selected_indices = inquire::MultiSelect::new(prompt.as_ref(), displayed_items)
         .with_default(&already_selected)
         .raw_prompt()
+        .into_diagnostic()
         .context("There's nothing to select from")?;
 
     // get the items for the selected indices
@@ -46,7 +48,7 @@ pub fn fuzzy_select_with_key<T>(
     items: &[T],
     prompt: impl AsRef<str>,
     f_display: impl Fn(&T) -> String,
-) -> anyhow::Result<&T> {
+) -> miette::Result<&T> {
     fuzzy_select_with_key_with_default(items, prompt, f_display, None)
 }
 
@@ -62,10 +64,10 @@ pub fn fuzzy_select_with_key_with_default<T>(
     prompt: impl AsRef<str>,
     f_display: impl Fn(&T) -> String,
     default_index: Option<usize>,
-) -> anyhow::Result<&T> {
+) -> miette::Result<&T> {
     // return `None` if we have nothing to select from
     if items.is_empty() {
-        anyhow::bail!("Nothing to select from. Aborting.")
+        miette::bail!("Nothing to select from. Aborting.")
     }
 
     let displayed_items = items.iter().map(f_display).collect::<Vec<_>>();
@@ -79,7 +81,7 @@ pub fn fuzzy_select_with_key_with_default<T>(
     }
 
     // select an item by key
-    let selected_index = dialogue.raw_prompt().map_err(anyhow::Error::from)?.index;
+    let selected_index = dialogue.raw_prompt().into_diagnostic()?.index;
 
     Ok(&items[selected_index])
 }
@@ -88,9 +90,33 @@ pub fn fuzzy_select_with_key_with_default<T>(
 ///
 /// - `y` -> `true`
 /// - `n` -> `false`
-pub fn confirm_with_prompt(prompt: &str) -> anyhow::Result<bool> {
-    inquire::Confirm::new(prompt)
+pub fn confirm_with_prompt(prompt: impl AsRef<str>) -> miette::Result<bool> {
+    inquire::Confirm::new(prompt.as_ref())
         .with_help_message("(y/n)?")
         .prompt()
-        .map_err(anyhow::Error::from)
+        .into_diagnostic()
+}
+
+/// Select a [`forgejo_api::structs::StateType`] and serialize it the right way into a [`String`]
+/// ... It has to be lowercase, otherwise the API will not detect it
+pub fn select_state(current_state: Option<StateType>) -> miette::Result<String> {
+    fuzzy_select_with_key(
+        &[StateType::Open, StateType::Closed],
+        "Select the desired state",
+        |f| format!("{f:?}"),
+    )
+    .or(current_state
+        .as_ref()
+        .context("Not even current issue state available, aborting!"))
+    .and_then(|state| {
+        serde_json::to_string(&state)
+            .into_diagnostic()
+            .context("Couldn't convert given `state` properly for the API call!")
+    })
+    .map(|state| {
+        state
+            .trim_start_matches('"')
+            .trim_end_matches('"')
+            .to_string()
+    })
 }
