@@ -1,14 +1,15 @@
 use std::path::PathBuf;
 use std::{env::current_dir, path::Path};
 
-use anyhow::Context;
 use clap::ValueEnum;
 use config::Config;
+use miette::{Context, IntoDiagnostic};
 use serde::{Deserialize, Serialize};
 use url::Url;
 
 use crate::paths::{berg_config_dir, config_path};
 use crate::render::table::TableWrapper;
+use crate::types::git::Git;
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, ValueEnum)]
 pub enum ConfigLocation {
@@ -18,7 +19,7 @@ pub enum ConfigLocation {
 }
 
 impl ConfigLocation {
-    pub fn path(self) -> anyhow::Result<PathBuf> {
+    pub fn path(self) -> miette::Result<PathBuf> {
         match self {
             ConfigLocation::Global => {
                 let global_path = config_path()?;
@@ -27,7 +28,9 @@ impl ConfigLocation {
                     .context("config path has parent directory")?;
                 Ok(global_path_dir.to_path_buf())
             }
-            ConfigLocation::Local => current_dir().context("Getting current directory failed!"),
+            ConfigLocation::Local => current_dir()
+                .into_diagnostic()
+                .context("Getting current directory failed!"),
             ConfigLocation::Stdout => unreachable!(
                 "Path of Stdout doesn't make sense. Impossible codepath. Please report this as an issue!"
             ),
@@ -89,8 +92,11 @@ impl BergConfig {
 
 impl Default for BergConfig {
     fn default() -> Self {
+        let base_url = Git::new()
+            .origin()
+            .and_then(|origin| origin.url().map(strip_base_url));
         Self {
-            base_url: String::from("codeberg.org/"),
+            base_url: base_url.unwrap_or(String::from("codeberg.org/")),
             protocol: String::from("https"),
             fancy_tables: true,
             no_color: false,
@@ -113,13 +119,15 @@ impl BergConfig {
     /// global and local configs exist, all existing options from the local config override the
     /// global configs options. On the other hand, if some options are not overridden, then the
     /// global ones are used in this scenario.
-    pub fn new() -> anyhow::Result<Self> {
-        let config = Self::raw()?.try_deserialize::<BergConfig>()?;
+    pub fn new() -> miette::Result<Self> {
+        let config = Self::raw()?
+            .try_deserialize::<BergConfig>()
+            .into_diagnostic()?;
         Ok(config)
     }
 
-    pub fn raw() -> anyhow::Result<Config> {
-        let local_config_path = current_dir().map(add_berg_config_file)?;
+    pub fn raw() -> miette::Result<Config> {
+        let local_config_path = current_dir().map(add_berg_config_file).into_diagnostic()?;
         let global_config_path = berg_config_dir().map(add_berg_config_file)?;
         let mut config_builder = Config::builder();
 
@@ -157,21 +165,24 @@ impl BergConfig {
         // add default values if no source has the value set
 
         for (field_name, default_value) in BergConfig::iter_default_field_value() {
-            config_builder = config_builder.set_default(field_name, default_value)?;
+            config_builder = config_builder
+                .set_default(field_name, default_value)
+                .into_diagnostic()?;
         }
 
-        config_builder.build().map_err(anyhow::Error::from)
+        config_builder.build().into_diagnostic()
     }
 }
 
 impl BergConfig {
-    pub fn url(&self) -> anyhow::Result<Url> {
+    pub fn url(&self) -> miette::Result<Url> {
         let url = format!(
             "{protoc}://{url}",
             protoc = self.protocol,
             url = self.base_url
         );
         Url::parse(url.as_str())
+            .into_diagnostic()
             .context("The protocol + base url in the config don't add up to a valid url")
     }
 
@@ -190,9 +201,7 @@ impl BergConfig {
             comfy_table::presets::NOTHING
         };
 
-        table.load_preset(preset);
-
-        table
+        table.load_preset(preset)
     }
 }
 
@@ -232,40 +241,46 @@ fn default_editor() -> String {
 mod tests {
     use super::*;
 
-    fn make_config(path: PathBuf, config: BergConfig) -> anyhow::Result<()> {
+    fn make_config(path: PathBuf, config: BergConfig) -> miette::Result<()> {
         let config_path = add_berg_config_file(path);
-        let toml = toml::to_string(&config).context("Failed to create config string!")?;
-        std::fs::write(config_path, toml).context("Failed to write config file!")?;
+        let toml = toml::to_string(&config)
+            .into_diagnostic()
+            .context("Failed to create config string!")?;
+        std::fs::write(config_path, toml)
+            .into_diagnostic()
+            .context("Failed to write config file!")?;
         Ok(())
     }
 
-    fn delete_config(path: PathBuf) -> anyhow::Result<()> {
+    fn delete_config(path: PathBuf) -> miette::Result<()> {
         let config_path = add_berg_config_file(path);
-        std::fs::remove_file(config_path).context("Failed to remove file")?;
+        std::fs::remove_file(config_path)
+            .into_diagnostic()
+            .context("Failed to remove file")?;
         Ok(())
     }
 
     #[test]
     #[ignore = "doesn't work on nix in 'ci' because of no r/w permissions on the system"]
-    fn berg_config_integration_test() -> anyhow::Result<()> {
+    fn berg_config_integration_test() -> miette::Result<()> {
         // ensure the directories are there while testing
         // (otherwise CI will fail)
-        let local_dir = current_dir()?;
-        std::fs::create_dir_all(local_dir)?;
+        let local_dir = current_dir().into_diagnostic()?;
+        std::fs::create_dir_all(local_dir).into_diagnostic()?;
         let global_dir = berg_config_dir()?;
-        std::fs::create_dir_all(global_dir)?;
+        std::fs::create_dir_all(global_dir).into_diagnostic()?;
 
         // test local config
         let config = BergConfig {
             base_url: String::from("local"),
             ..Default::default()
         };
-        make_config(current_dir()?, config)?;
+        make_config(current_dir().into_diagnostic()?, config)?;
         let config = BergConfig::new();
         assert!(config.is_ok(), "{config:?}");
         let config = config.unwrap();
         assert_eq!(config.base_url.as_str(), "local");
-        delete_config(current_dir()?)?;
+        delete_config(current_dir().into_diagnostic()?)?;
 
         // test global config
         let config = BergConfig {
@@ -292,7 +307,7 @@ mod tests {
                 base_url: String::from("local"),
                 ..Default::default()
             };
-            make_config(current_dir()?, config)?;
+            make_config(current_dir().into_diagnostic()?, config)?;
         }
         {
             // global
@@ -306,9 +321,57 @@ mod tests {
         assert!(config.is_ok(), "{config:?}");
         let config = config.unwrap();
         assert_eq!(config.base_url.as_str(), "local");
-        delete_config(current_dir()?)?;
+        delete_config(current_dir().into_diagnostic()?)?;
         delete_config(berg_config_dir()?)?;
 
         Ok(())
     }
 }
+
+/// small helper function to get the base url from a full git remote url
+///
+/// There are different formats of remote urls that are all taken into account here, e.g.
+///
+/// - https
+/// - ssh of various kinds of detail
+fn strip_base_url(url: impl AsRef<str>) -> String {
+    let url = url.as_ref();
+    let url = url.split_once("//").map(|(_proto, url)| url).unwrap_or(url);
+    let url = url.split_once("@").map(|(_user, url)| url).unwrap_or(url);
+    let url = url.split_once("/").map(|(base, _path)| base).unwrap_or(url);
+    let url = url.split_once(":").map(|(base, _user)| base).unwrap_or(url);
+    format!("{url}/")
+}
+
+#[cfg(test)]
+mod strip_base_url {
+    use super::strip_base_url;
+    #[test]
+    fn https_works() {
+        assert_eq!(
+            strip_base_url("https://codeberg.org/example.com"),
+            "codeberg.org/"
+        );
+    }
+
+    #[test]
+    fn ssh_works() {
+        assert_eq!(
+            strip_base_url("git@codeberg.org:Aviac/codeberg-cli.git"),
+            "codeberg.org/"
+        );
+    }
+
+    #[test]
+    fn ssh_detailed_works() {
+        assert_eq!(
+            strip_base_url("ssh://git@example.com:1312/foo/bar.git"),
+            "example.com/"
+        );
+    }
+
+    #[test]
+    fn domain_and_port_no_protoc() {
+        assert_eq!(strip_base_url("example.com:1312"), "example.com/");
+    }
+}
