@@ -1,7 +1,7 @@
 use std::ops::{Deref, DerefMut};
 
-use anyhow::Context;
 use derive_new::new;
+use miette::{Context, IntoDiagnostic};
 
 use crate::paths::token_path;
 
@@ -22,9 +22,15 @@ impl DerefMut for Token {
 }
 
 impl Token {
-    pub fn read_from_data_dir() -> anyhow::Result<Self> {
-        let token_path = token_path()?;
-        let token = std::fs::read_to_string(token_path).context("Reading token failed!")?;
+    pub fn read_from_data_dir(instance: impl AsRef<str>) -> miette::Result<Self> {
+        let token_path = token_path(instance)?;
+        let token = std::fs::read_to_string(token_path)
+            .into_diagnostic()
+            .context("Reading token from '{token_path}' failed!")?;
         Ok(Self(token))
     }
+
+    pub fn read_from_env() -> miette::Result<Self> {
+        std::env::var("BERG_TOKEN").into_diagnostic().map(Token)
+    }
 }
